% Computations performed for Heinken, A,. and Thiele, I. 2015, Appl Environ
% Microbiol 81:4049-4061
% Predicts pairwise growth in two-microbe pairs with and without the
% enterocyte
% Three diets with and without oxygen

% This will load in the pairwise models one by one. The pairwise
% interactions will be calculated by calling the script
% "calculateMicrobeGrowth".
% The growth rates determined by flux balance analysis will be stored in 
% the output file "PairwiseGrowth". The flux spans determined by flux 
% variability analysis will be stored in the output file "FVASolutions".

% The script requires the following:
% - COBRA Toolbox
% - Script solveCobraLPCPLEX with Tomlab cplex solver
% fastFVA (Gudmundsson, S. and Thiele, I., BMC Bioinformatics 2010, 11:489)

% In case you don't have the Tomlab cplex solver, you need to edit the
% script calculateMicrobeGrowth on line 80.

% If you don't have fastFVA installed or if you don't want to perform flux
% variability analysis, please uncomment the indictaed part in the script
% calculateMicrobeGrowth (line 99-118).

GrowthRates=[];
FVASolutions=[];

save GrowthRates GrowthRates;
save FVASolutions FVASolutions;

% Western diet, without oxygen, without enterocyte
% calculate microbe growth when grown separately

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BT',modelJoint,'WesternNoOx');

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FP',modelJoint,'WesternNoOx');

load modelJoint_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LP',modelJoint,'WesternNoOx');

load modelJoint_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LL',modelJoint,'WesternNoOx');

load modelJoint_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ST',modelJoint,'WesternNoOx');

load modelJoint_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KP',modelJoint,'WesternNoOx');

load modelJoint_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STy',modelJoint,'WesternNoOx');

load modelJoint_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('EC',modelJoint,'WesternNoOx');

load modelJoint_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECs',modelJoint,'WesternNoOx');

load modelJoint_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECe',modelJoint,'WesternNoOx');

% Western diet, without oxygen, without enterocyte
% calculate microbe growth when grown in all pairwise combinations

load modelJoint_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTFP',modelJoint,'WesternNoOx');

load modelJoint_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLP',modelJoint,'WesternNoOx');

load modelJoint_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLL',modelJoint,'WesternNoOx');

load modelJoint_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTST',modelJoint,'WesternNoOx');

load modelJoint_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTKP',modelJoint,'WesternNoOx');

load modelJoint_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTSTy',modelJoint,'WesternNoOx');

load modelJoint_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTEC',modelJoint,'WesternNoOx');

load modelJoint_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECs',modelJoint,'WesternNoOx');

load modelJoint_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECe',modelJoint,'WesternNoOx');

load modelJoint_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLP',modelJoint,'WesternNoOx');

load modelJoint_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLL',modelJoint,'WesternNoOx');

load modelJoint_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPST',modelJoint,'WesternNoOx');

load modelJoint_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPKP',modelJoint,'WesternNoOx');

load modelJoint_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPSTy',modelJoint,'WesternNoOx');

load modelJoint_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPEC',modelJoint,'WesternNoOx');

load modelJoint_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECs',modelJoint,'WesternNoOx');

load modelJoint_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECe',modelJoint,'WesternNoOx');

load modelJoint_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPLL',modelJoint,'WesternNoOx');

load modelJoint_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPST',modelJoint,'WesternNoOx');

load modelJoint_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPKP',modelJoint,'WesternNoOx');

load modelJoint_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPSTy',modelJoint,'WesternNoOx');

load modelJoint_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPEC',modelJoint,'WesternNoOx');

load modelJoint_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECs',modelJoint,'WesternNoOx');

load modelJoint_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECe',modelJoint,'WesternNoOx');

load modelJoint_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLST',modelJoint,'WesternNoOx');

load modelJoint_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLKP',modelJoint,'WesternNoOx');

load modelJoint_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLSTy',modelJoint,'WesternNoOx');

load modelJoint_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLEC',modelJoint,'WesternNoOx');

load modelJoint_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECs',modelJoint,'WesternNoOx');

load modelJoint_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECe',modelJoint,'WesternNoOx');

load modelJoint_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STKP',modelJoint,'WesternNoOx');

load modelJoint_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STSTy',modelJoint,'WesternNoOx');

load modelJoint_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STEC',modelJoint,'WesternNoOx');

load modelJoint_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECs',modelJoint,'WesternNoOx');

load modelJoint_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECe',modelJoint,'WesternNoOx');

load modelJoint_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPSTy',modelJoint,'WesternNoOx');

load modelJoint_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPEC',modelJoint,'WesternNoOx');

load modelJoint_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECs',modelJoint,'WesternNoOx');

load modelJoint_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECe',modelJoint,'WesternNoOx');

load modelJoint_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyEC',modelJoint,'WesternNoOx');

load modelJoint_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECs',modelJoint,'WesternNoOx');

load modelJoint_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECe',modelJoint,'WesternNoOx');

load modelJoint_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECs',modelJoint,'WesternNoOx');

load modelJoint_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECe',modelJoint,'WesternNoOx');

load modelJoint_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECsECe',modelJoint,'WesternNoOx');


load FVASolutions.mat;
save FVASolutions_Microbes_WesternNoOx.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;

% High fiber diet, without oxygen, without enterocyte
% calculate microbe growth when grown separately

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BT',modelJoint,'HighFiberNoOx');

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FP',modelJoint,'HighFiberNoOx');

load modelJoint_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LP',modelJoint,'HighFiberNoOx');

load modelJoint_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LL',modelJoint,'HighFiberNoOx');

load modelJoint_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ST',modelJoint,'HighFiberNoOx');

load modelJoint_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KP',modelJoint,'HighFiberNoOx');

load modelJoint_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STy',modelJoint,'HighFiberNoOx');

load modelJoint_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('EC',modelJoint,'HighFiberNoOx');

load modelJoint_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECs',modelJoint,'HighFiberNoOx');

load modelJoint_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECe',modelJoint,'HighFiberNoOx');


% High fiber diet, without oxygen, without enterocyte
% calculate microbe growth when grown in all pairwise combinations

load modelJoint_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTFP',modelJoint,'HighFiberNoOx');

load modelJoint_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLP',modelJoint,'HighFiberNoOx');

load modelJoint_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLL',modelJoint,'HighFiberNoOx');

load modelJoint_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTST',modelJoint,'HighFiberNoOx');

load modelJoint_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTKP',modelJoint,'HighFiberNoOx');

load modelJoint_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTSTy',modelJoint,'HighFiberNoOx');

load modelJoint_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTEC',modelJoint,'HighFiberNoOx');

load modelJoint_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECs',modelJoint,'HighFiberNoOx');

load modelJoint_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECe',modelJoint,'HighFiberNoOx');

load modelJoint_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLP',modelJoint,'HighFiberNoOx');

load modelJoint_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLL',modelJoint,'HighFiberNoOx');

load modelJoint_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPST',modelJoint,'HighFiberNoOx');

load modelJoint_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPKP',modelJoint,'HighFiberNoOx');

load modelJoint_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPSTy',modelJoint,'HighFiberNoOx');

load modelJoint_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPEC',modelJoint,'HighFiberNoOx');

load modelJoint_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECs',modelJoint,'HighFiberNoOx');

load modelJoint_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECe',modelJoint,'HighFiberNoOx');

load modelJoint_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPLL',modelJoint,'HighFiberNoOx');

load modelJoint_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPST',modelJoint,'HighFiberNoOx');

load modelJoint_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPKP',modelJoint,'HighFiberNoOx');

load modelJoint_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPSTy',modelJoint,'HighFiberNoOx');

load modelJoint_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPEC',modelJoint,'HighFiberNoOx');

load modelJoint_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECs',modelJoint,'HighFiberNoOx');

load modelJoint_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECe',modelJoint,'HighFiberNoOx');

load modelJoint_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLST',modelJoint,'HighFiberNoOx');

load modelJoint_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLKP',modelJoint,'HighFiberNoOx');

load modelJoint_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLSTy',modelJoint,'HighFiberNoOx');

load modelJoint_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLEC',modelJoint,'HighFiberNoOx');

load modelJoint_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECs',modelJoint,'HighFiberNoOx');

load modelJoint_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECe',modelJoint,'HighFiberNoOx');

load modelJoint_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STKP',modelJoint,'HighFiberNoOx');

load modelJoint_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STSTy',modelJoint,'HighFiberNoOx');

load modelJoint_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STEC',modelJoint,'HighFiberNoOx');

load modelJoint_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECs',modelJoint,'HighFiberNoOx');

load modelJoint_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECe',modelJoint,'HighFiberNoOx');

load modelJoint_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPSTy',modelJoint,'HighFiberNoOx');

load modelJoint_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPEC',modelJoint,'HighFiberNoOx');

load modelJoint_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECs',modelJoint,'HighFiberNoOx');

load modelJoint_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECe',modelJoint,'HighFiberNoOx');

load modelJoint_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyEC',modelJoint,'HighFiberNoOx');

load modelJoint_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECs',modelJoint,'HighFiberNoOx');

load modelJoint_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECe',modelJoint,'HighFiberNoOx');

load modelJoint_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECs',modelJoint,'HighFiberNoOx');

load modelJoint_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECe',modelJoint,'HighFiberNoOx');

load modelJoint_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECsECe',modelJoint,'HighFiberNoOx');


load FVASolutions.mat;
save FVASolutions_Microbes_HighFiberNoOx.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% Protein diet, without oxygen, without enterocyte
% calculate microbe growth when grown separately

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BT',modelJoint,'ProteinNoOx');

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FP',modelJoint,'ProteinNoOx');

load modelJoint_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LP',modelJoint,'ProteinNoOx');

load modelJoint_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LL',modelJoint,'ProteinNoOx');

load modelJoint_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ST',modelJoint,'ProteinNoOx');

load modelJoint_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KP',modelJoint,'ProteinNoOx');

load modelJoint_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STy',modelJoint,'ProteinNoOx');

load modelJoint_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('EC',modelJoint,'ProteinNoOx');

load modelJoint_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECs',modelJoint,'ProteinNoOx');

load modelJoint_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECe',modelJoint,'ProteinNoOx');


% Protein diet, without oxygen, without enterocyte
% calculate microbe growth when grown in all pairwise combinations

load modelJoint_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTFP',modelJoint,'ProteinNoOx');

load modelJoint_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLP',modelJoint,'ProteinNoOx');

load modelJoint_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLL',modelJoint,'ProteinNoOx');

load modelJoint_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTST',modelJoint,'ProteinNoOx');

load modelJoint_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTKP',modelJoint,'ProteinNoOx');

load modelJoint_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTSTy',modelJoint,'ProteinNoOx');

load modelJoint_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTEC',modelJoint,'ProteinNoOx');

load modelJoint_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECs',modelJoint,'ProteinNoOx');

load modelJoint_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECe',modelJoint,'ProteinNoOx');

load modelJoint_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLP',modelJoint,'ProteinNoOx');

load modelJoint_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLL',modelJoint,'ProteinNoOx');

load modelJoint_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPST',modelJoint,'ProteinNoOx');

load modelJoint_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPKP',modelJoint,'ProteinNoOx');

load modelJoint_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPSTy',modelJoint,'ProteinNoOx');

load modelJoint_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPEC',modelJoint,'ProteinNoOx');

load modelJoint_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECs',modelJoint,'ProteinNoOx');

load modelJoint_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECe',modelJoint,'ProteinNoOx');

load modelJoint_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPLL',modelJoint,'ProteinNoOx');

load modelJoint_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPST',modelJoint,'ProteinNoOx');

load modelJoint_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPKP',modelJoint,'ProteinNoOx');

load modelJoint_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPSTy',modelJoint,'ProteinNoOx');

load modelJoint_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPEC',modelJoint,'ProteinNoOx');

load modelJoint_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECs',modelJoint,'ProteinNoOx');

load modelJoint_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECe',modelJoint,'ProteinNoOx');

load modelJoint_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLST',modelJoint,'ProteinNoOx');

load modelJoint_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLKP',modelJoint,'ProteinNoOx');

load modelJoint_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLSTy',modelJoint,'ProteinNoOx');

load modelJoint_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLEC',modelJoint,'ProteinNoOx');

load modelJoint_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECs',modelJoint,'ProteinNoOx');

load modelJoint_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECe',modelJoint,'ProteinNoOx');

load modelJoint_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STKP',modelJoint,'ProteinNoOx');

load modelJoint_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STSTy',modelJoint,'ProteinNoOx');

load modelJoint_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STEC',modelJoint,'ProteinNoOx');

load modelJoint_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECs',modelJoint,'ProteinNoOx');

load modelJoint_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECe',modelJoint,'ProteinNoOx');

load modelJoint_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPSTy',modelJoint,'ProteinNoOx');

load modelJoint_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPEC',modelJoint,'ProteinNoOx');

load modelJoint_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECs',modelJoint,'ProteinNoOx');

load modelJoint_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECe',modelJoint,'ProteinNoOx');

load modelJoint_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyEC',modelJoint,'ProteinNoOx');

load modelJoint_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECs',modelJoint,'ProteinNoOx');

load modelJoint_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECe',modelJoint,'ProteinNoOx');

load modelJoint_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECs',modelJoint,'ProteinNoOx');

load modelJoint_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECe',modelJoint,'ProteinNoOx');

load modelJoint_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECsECe',modelJoint,'ProteinNoOx');


load FVASolutions.mat;
save FVASolutions_Microbes_ProteinNoOx.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% Western diet, with oxygen, without enterocyte
% calculate microbe growth when grown separately

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BT',modelJoint,'Western');

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FP',modelJoint,'Western');

load modelJoint_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LP',modelJoint,'Western');

load modelJoint_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LL',modelJoint,'Western');

load modelJoint_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ST',modelJoint,'Western');

load modelJoint_BTHP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HP',modelJoint,'Western');

load modelJoint_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KP',modelJoint,'Western');

load modelJoint_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STy',modelJoint,'Western');

load modelJoint_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('EC',modelJoint,'Western');

load modelJoint_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECs',modelJoint,'Western');

load modelJoint_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECe',modelJoint,'Western');


% Western diet, with oxygen, without enterocyte
% calculate microbe growth when grown pairwise in all combinations

load modelJoint_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTFP',modelJoint,'Western');

load modelJoint_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLP',modelJoint,'Western');

load modelJoint_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLL',modelJoint,'Western');

load modelJoint_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTST',modelJoint,'Western');

load modelJoint_BTHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTHP',modelJoint,'Western');

load modelJoint_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTKP',modelJoint,'Western');

load modelJoint_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTSTy',modelJoint,'Western');

load modelJoint_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTEC',modelJoint,'Western');

load modelJoint_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECs',modelJoint,'Western');

load modelJoint_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECe',modelJoint,'Western');

load modelJoint_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLP',modelJoint,'Western');

load modelJoint_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLL',modelJoint,'Western');

load modelJoint_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPST',modelJoint,'Western');

load modelJoint_FPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPHP',modelJoint,'Western');

load modelJoint_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPKP',modelJoint,'Western');

load modelJoint_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPSTy',modelJoint,'Western');

load modelJoint_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPEC',modelJoint,'Western');

load modelJoint_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECs',modelJoint,'Western');

load modelJoint_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECe',modelJoint,'Western');

load modelJoint_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPLL',modelJoint,'Western');

load modelJoint_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPST',modelJoint,'Western');

load modelJoint_LPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPHP',modelJoint,'Western');

load modelJoint_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPKP',modelJoint,'Western');

load modelJoint_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPSTy',modelJoint,'Western');

load modelJoint_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPEC',modelJoint,'Western');

load modelJoint_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECs',modelJoint,'Western');

load modelJoint_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECe',modelJoint,'Western');

load modelJoint_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLST',modelJoint,'Western');

load modelJoint_LLHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLHP',modelJoint,'Western');

load modelJoint_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLKP',modelJoint,'Western');

load modelJoint_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLSTy',modelJoint,'Western');

load modelJoint_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLEC',modelJoint,'Western');

load modelJoint_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECs',modelJoint,'Western');

load modelJoint_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECe',modelJoint,'Western');

load modelJoint_STHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STHP',modelJoint,'Western');

load modelJoint_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STKP',modelJoint,'Western');

load modelJoint_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STSTy',modelJoint,'Western');

load modelJoint_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STEC',modelJoint,'Western');

load modelJoint_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECs',modelJoint,'Western');

load modelJoint_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECe',modelJoint,'Western');

load modelJoint_HPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPKP',modelJoint,'Western');

load modelJoint_HPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPSTy',modelJoint,'Western');

load modelJoint_HPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPEC',modelJoint,'Western');

load modelJoint_HPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPECs',modelJoint,'Western');

load modelJoint_HPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPECe',modelJoint,'Western');

load modelJoint_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPSTy',modelJoint,'Western');

load modelJoint_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPEC',modelJoint,'Western');

load modelJoint_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECs',modelJoint,'Western');

load modelJoint_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECe',modelJoint,'Western');

load modelJoint_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyEC',modelJoint,'Western');

load modelJoint_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECs',modelJoint,'Western');

load modelJoint_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECe',modelJoint,'Western');

load modelJoint_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECs',modelJoint,'Western');

load modelJoint_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECe',modelJoint,'Western');

load modelJoint_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECsECe',modelJoint,'Western');


load FVASolutions.mat;
save FVASolutions_Microbes_Western.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% High fiber diet, with oxygen, without enterocyte
% calculate microbe growth when grown separately

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BT',modelJoint,'HighFiber');

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FP',modelJoint,'HighFiber');

load modelJoint_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LP',modelJoint,'HighFiber');

load modelJoint_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LL',modelJoint,'HighFiber');

load modelJoint_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ST',modelJoint,'HighFiber');

load modelJoint_BTHP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HP',modelJoint,'HighFiber');

load modelJoint_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KP',modelJoint,'HighFiber');

load modelJoint_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STy',modelJoint,'HighFiber');

load modelJoint_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('EC',modelJoint,'HighFiber');

load modelJoint_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECs',modelJoint,'HighFiber');

load modelJoint_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECe',modelJoint,'HighFiber');

% microbe pairs
load modelJoint_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTFP',modelJoint,'HighFiber');

load modelJoint_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLP',modelJoint,'HighFiber');

load modelJoint_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLL',modelJoint,'HighFiber');

load modelJoint_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTST',modelJoint,'HighFiber');

load modelJoint_BTHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTHP',modelJoint,'HighFiber');

load modelJoint_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTKP',modelJoint,'HighFiber');

load modelJoint_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTSTy',modelJoint,'HighFiber');

load modelJoint_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTEC',modelJoint,'HighFiber');

load modelJoint_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECs',modelJoint,'HighFiber');

load modelJoint_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECe',modelJoint,'HighFiber');

load modelJoint_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLP',modelJoint,'HighFiber');

load modelJoint_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLL',modelJoint,'HighFiber');

load modelJoint_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPST',modelJoint,'HighFiber');

load modelJoint_FPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPHP',modelJoint,'HighFiber');

load modelJoint_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPKP',modelJoint,'HighFiber');

load modelJoint_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPSTy',modelJoint,'HighFiber');

load modelJoint_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPEC',modelJoint,'HighFiber');

load modelJoint_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECs',modelJoint,'HighFiber');

load modelJoint_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECe',modelJoint,'HighFiber');

load modelJoint_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPLL',modelJoint,'HighFiber');

load modelJoint_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPST',modelJoint,'HighFiber');

load modelJoint_LPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPHP',modelJoint,'HighFiber');

load modelJoint_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPKP',modelJoint,'HighFiber');

load modelJoint_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPSTy',modelJoint,'HighFiber');

load modelJoint_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPEC',modelJoint,'HighFiber');

load modelJoint_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECs',modelJoint,'HighFiber');

load modelJoint_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECe',modelJoint,'HighFiber');

load modelJoint_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLST',modelJoint,'HighFiber');

load modelJoint_LLHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLHP',modelJoint,'HighFiber');

load modelJoint_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLKP',modelJoint,'HighFiber');

load modelJoint_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLSTy',modelJoint,'HighFiber');

load modelJoint_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLEC',modelJoint,'HighFiber');

load modelJoint_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECs',modelJoint,'HighFiber');

load modelJoint_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECe',modelJoint,'HighFiber');

load modelJoint_STHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STHP',modelJoint,'HighFiber');

load modelJoint_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STKP',modelJoint,'HighFiber');

load modelJoint_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STSTy',modelJoint,'HighFiber');

load modelJoint_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STEC',modelJoint,'HighFiber');

load modelJoint_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECs',modelJoint,'HighFiber');

load modelJoint_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECe',modelJoint,'HighFiber');

load modelJoint_HPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPKP',modelJoint,'HighFiber');

load modelJoint_HPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPSTy',modelJoint,'HighFiber');

load modelJoint_HPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPEC',modelJoint,'HighFiber');

load modelJoint_HPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPECs',modelJoint,'HighFiber');

load modelJoint_HPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPECe',modelJoint,'HighFiber');

load modelJoint_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPSTy',modelJoint,'HighFiber');

load modelJoint_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPEC',modelJoint,'HighFiber');

load modelJoint_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECs',modelJoint,'HighFiber');

load modelJoint_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECe',modelJoint,'HighFiber');

load modelJoint_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyEC',modelJoint,'HighFiber');

load modelJoint_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECs',modelJoint,'HighFiber');

load modelJoint_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECe',modelJoint,'HighFiber');

load modelJoint_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECs',modelJoint,'HighFiber');

load modelJoint_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECe',modelJoint,'HighFiber');

load modelJoint_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECsECe',modelJoint,'HighFiber');


load FVASolutions.mat;
save FVASolutions_Microbes_HighFiber.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% Protein diet, with oxygen, without enterocyte
% calculate microbe growth when grown separately

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BT',modelJoint,'Protein');

load modelJoint_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FP',modelJoint,'Protein');

load modelJoint_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LP',modelJoint,'Protein');

load modelJoint_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LL',modelJoint,'Protein');

load modelJoint_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ST',modelJoint,'Protein');

load modelJoint_BTHP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HP',modelJoint,'Protein');

load modelJoint_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KP',modelJoint,'Protein');

load modelJoint_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STy',modelJoint,'Protein');

load modelJoint_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('EC',modelJoint,'Protein');

load modelJoint_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECs',modelJoint,'Protein');

load modelJoint_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECe',modelJoint,'Protein');


% Protein diet, with oxygen, without enterocyte
% calculate microbe growth when grown pairwise in all combinations

load modelJoint_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTFP',modelJoint,'Protein');

load modelJoint_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLP',modelJoint,'Protein');

load modelJoint_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTLL',modelJoint,'Protein');

load modelJoint_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTST',modelJoint,'Protein');

load modelJoint_BTHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTHP',modelJoint,'Protein');

load modelJoint_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTKP',modelJoint,'Protein');

load modelJoint_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTSTy',modelJoint,'Protein');

load modelJoint_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTEC',modelJoint,'Protein');

load modelJoint_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECs',modelJoint,'Protein');

load modelJoint_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('BTECe',modelJoint,'Protein');

load modelJoint_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLP',modelJoint,'Protein');

load modelJoint_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPLL',modelJoint,'Protein');

load modelJoint_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPST',modelJoint,'Protein');

load modelJoint_FPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPHP',modelJoint,'Protein');

load modelJoint_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPKP',modelJoint,'Protein');

load modelJoint_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPSTy',modelJoint,'Protein');

load modelJoint_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPEC',modelJoint,'Protein');

load modelJoint_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECs',modelJoint,'Protein');

load modelJoint_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('FPECe',modelJoint,'Protein');

load modelJoint_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPLL',modelJoint,'Protein');

load modelJoint_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPST',modelJoint,'Protein');

load modelJoint_LPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPHP',modelJoint,'Protein');

load modelJoint_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPKP',modelJoint,'Protein');

load modelJoint_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPSTy',modelJoint,'Protein');

load modelJoint_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPEC',modelJoint,'Protein');

load modelJoint_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECs',modelJoint,'Protein');

load modelJoint_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LPECe',modelJoint,'Protein');

load modelJoint_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLST',modelJoint,'Protein');

load modelJoint_LLHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLHP',modelJoint,'Protein');

load modelJoint_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLKP',modelJoint,'Protein');

load modelJoint_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLSTy',modelJoint,'Protein');

load modelJoint_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLEC',modelJoint,'Protein');

load modelJoint_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECs',modelJoint,'Protein');

load modelJoint_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('LLECe',modelJoint,'Protein');

load modelJoint_STHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STHP',modelJoint,'Protein');

load modelJoint_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STKP',modelJoint,'Protein');

load modelJoint_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STSTy',modelJoint,'Protein');

load modelJoint_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STEC',modelJoint,'Protein');

load modelJoint_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECs',modelJoint,'Protein');

load modelJoint_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STECe',modelJoint,'Protein');

load modelJoint_HPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPKP',modelJoint,'Protein');

load modelJoint_HPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPSTy',modelJoint,'Protein');

load modelJoint_HPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPEC',modelJoint,'Protein');

load modelJoint_HPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPECs',modelJoint,'Protein');

load modelJoint_HPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('HPECe',modelJoint,'Protein');

load modelJoint_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPSTy',modelJoint,'Protein');

load modelJoint_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPEC',modelJoint,'Protein');

load modelJoint_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECs',modelJoint,'Protein');

load modelJoint_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('KPECe',modelJoint,'Protein');

load modelJoint_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyEC',modelJoint,'Protein');

load modelJoint_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECs',modelJoint,'Protein');

load modelJoint_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('STyECe',modelJoint,'Protein');

load modelJoint_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECs',modelJoint,'Protein');

load modelJoint_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECECe',modelJoint,'Protein');

load modelJoint_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('ECsECe',modelJoint,'Protein');


load FVASolutions.mat;
save FVASolutions_Microbes_Protein.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% Western diet, without oxygen, with enterocyte
% calculate microbe growth when grown separately

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BT',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LL',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ST',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STy',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_EC',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECe',modelJoint,'WesternNoOx');


% Western diet, without oxygen, with enterocyte
% calculate microbe growth when grown pairwise in all combinations

load modelJoint_Enterocyte_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTFP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLL',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTST',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTKP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTSTy',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTEC',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECe',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLL',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPST',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPKP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPSTy',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPEC',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECe',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPLL',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPST',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPKP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPSTy',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPEC',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECe',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLST',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLKP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLSTy',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLEC',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECe',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STKP',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STSTy',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STEC',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECe',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPSTy',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPEC',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECe',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyEC',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECe',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECs',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECe',modelJoint,'WesternNoOx');

load modelJoint_Enterocyte_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECsECe',modelJoint,'WesternNoOx');


load FVASolutions.mat;
save FVASolutions_IEC_Microbes_WesternNoOx.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% High fiber diet, without oxygen, with enterocyte
% calculate microbe growth when grown separately

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BT',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LL',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ST',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STy',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_EC',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECe',modelJoint,'HighFiberNoOx');


% High fiber diet, without oxygen, with enterocyte
% calculate microbe growth when grown pairwise in all combinations

load modelJoint_Enterocyte_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTFP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLL',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTST',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTKP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTSTy',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTEC',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECe',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLL',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPST',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPKP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPSTy',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPEC',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECe',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPLL',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPST',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPKP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPSTy',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPEC',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECe',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLST',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLKP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLSTy',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLEC',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECe',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STKP',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STSTy',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STEC',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECe',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPSTy',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPEC',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECe',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyEC',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECe',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECs',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECe',modelJoint,'HighFiberNoOx');

load modelJoint_Enterocyte_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECsECe',modelJoint,'HighFiberNoOx');


load FVASolutions.mat;
save FVASolutions_IEC_Microbes_HighFiberNoOx.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% Protein diet, without oxygen, with enterocyte
% calculate microbe growth when grown separately

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BT',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LL',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ST',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STy',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_EC',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECe',modelJoint,'ProteinNoOx');


% Protein diet, without oxygen, with enterocyte
% calculate microbe growth when grown pairwise in all combinations

load modelJoint_Enterocyte_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTFP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLL',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTST',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTKP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTSTy',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTEC',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECe',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLL',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPST',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPKP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPSTy',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPEC',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECe',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPLL',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPST',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPKP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPSTy',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPEC',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECe',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLST',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLKP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLSTy',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLEC',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECe',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STKP',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STSTy',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STEC',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECe',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPSTy',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPEC',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECe',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyEC',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECe',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECs',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECe',modelJoint,'ProteinNoOx');

load modelJoint_Enterocyte_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECsECe',modelJoint,'ProteinNoOx');


load FVASolutions.mat;
save FVASolutions_IEC_Microbes_ProteinNoOx.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% Western diet, with oxygen, with enterocyte
% calculate microbe growth when grown separately

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BT',modelJoint,'Western');

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FP',modelJoint,'Western');

load modelJoint_Enterocyte_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LP',modelJoint,'Western');

load modelJoint_Enterocyte_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LL',modelJoint,'Western');

load modelJoint_Enterocyte_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ST',modelJoint,'Western');

load modelJoint_Enterocyte_BTHP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HP',modelJoint,'Western');

load modelJoint_Enterocyte_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KP',modelJoint,'Western');

load modelJoint_Enterocyte_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STy',modelJoint,'Western');

load modelJoint_Enterocyte_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_EC',modelJoint,'Western');

load modelJoint_Enterocyte_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECs',modelJoint,'Western');

load modelJoint_Enterocyte_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECe',modelJoint,'Western');


% Western diet, with oxygen, with enterocyte
% calculate microbe growth when grown pairwise in all combinations

load modelJoint_Enterocyte_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTFP',modelJoint,'Western');

load modelJoint_Enterocyte_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLP',modelJoint,'Western');

load modelJoint_Enterocyte_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLL',modelJoint,'Western');

load modelJoint_Enterocyte_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTST',modelJoint,'Western');

load modelJoint_Enterocyte_BTHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTHP',modelJoint,'Western');

load modelJoint_Enterocyte_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTKP',modelJoint,'Western');

load modelJoint_Enterocyte_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTSTy',modelJoint,'Western');

load modelJoint_Enterocyte_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTEC',modelJoint,'Western');

load modelJoint_Enterocyte_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECs',modelJoint,'Western');

load modelJoint_Enterocyte_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECe',modelJoint,'Western');

load modelJoint_Enterocyte_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLP',modelJoint,'Western');

load modelJoint_Enterocyte_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLL',modelJoint,'Western');

load modelJoint_Enterocyte_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPST',modelJoint,'Western');

load modelJoint_Enterocyte_FPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPHP',modelJoint,'Western');

load modelJoint_Enterocyte_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPKP',modelJoint,'Western');

load modelJoint_Enterocyte_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPSTy',modelJoint,'Western');

load modelJoint_Enterocyte_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPEC',modelJoint,'Western');

load modelJoint_Enterocyte_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECs',modelJoint,'Western');

load modelJoint_Enterocyte_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECe',modelJoint,'Western');

load modelJoint_Enterocyte_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPLL',modelJoint,'Western');

load modelJoint_Enterocyte_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPST',modelJoint,'Western');

load modelJoint_Enterocyte_LPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPHP',modelJoint,'Western');

load modelJoint_Enterocyte_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPKP',modelJoint,'Western');

load modelJoint_Enterocyte_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPSTy',modelJoint,'Western');

load modelJoint_Enterocyte_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPEC',modelJoint,'Western');

load modelJoint_Enterocyte_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECs',modelJoint,'Western');

load modelJoint_Enterocyte_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECe',modelJoint,'Western');

load modelJoint_Enterocyte_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLST',modelJoint,'Western');

load modelJoint_Enterocyte_LLHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLHP',modelJoint,'Western');

load modelJoint_Enterocyte_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLKP',modelJoint,'Western');

load modelJoint_Enterocyte_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLSTy',modelJoint,'Western');

load modelJoint_Enterocyte_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLEC',modelJoint,'Western');

load modelJoint_Enterocyte_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECs',modelJoint,'Western');

load modelJoint_Enterocyte_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECe',modelJoint,'Western');

load modelJoint_Enterocyte_STHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STHP',modelJoint,'Western');

load modelJoint_Enterocyte_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STKP',modelJoint,'Western');

load modelJoint_Enterocyte_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STSTy',modelJoint,'Western');

load modelJoint_Enterocyte_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STEC',modelJoint,'Western');

load modelJoint_Enterocyte_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECs',modelJoint,'Western');

load modelJoint_Enterocyte_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECe',modelJoint,'Western');

load modelJoint_Enterocyte_HPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPKP',modelJoint,'Western');

load modelJoint_Enterocyte_HPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPSTy',modelJoint,'Western');

load modelJoint_Enterocyte_HPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPEC',modelJoint,'Western');

load modelJoint_Enterocyte_HPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPECs',modelJoint,'Western');

load modelJoint_Enterocyte_HPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPECe',modelJoint,'Western');

load modelJoint_Enterocyte_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPSTy',modelJoint,'Western');

load modelJoint_Enterocyte_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPEC',modelJoint,'Western');

load modelJoint_Enterocyte_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECs',modelJoint,'Western');

load modelJoint_Enterocyte_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECe',modelJoint,'Western');

load modelJoint_Enterocyte_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyEC',modelJoint,'Western');

load modelJoint_Enterocyte_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECs',modelJoint,'Western');

load modelJoint_Enterocyte_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECe',modelJoint,'Western');

load modelJoint_Enterocyte_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECs',modelJoint,'Western');

load modelJoint_Enterocyte_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECe',modelJoint,'Western');

load modelJoint_Enterocyte_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECsECe',modelJoint,'Western');


load FVASolutions.mat;
save FVASolutions_IEC_Microbes_Western.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% High fiber diet, with oxygen, with enterocyte
% calculate microbe growth when grown separately

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BT',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LL',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ST',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTHP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STy',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_EC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECe',modelJoint,'HighFiber');


% High fiber diet, with oxygen, with enterocyte
% calculate microbe growth when grown pairwise in all combinations

load modelJoint_Enterocyte_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTFP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLL',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTST',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTHP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTKP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTSTy',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTEC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLL',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPST',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPHP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPKP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPSTy',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPEC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPLL',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPST',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPHP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPKP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPSTy',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPEC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLST',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LLHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLHP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLKP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLSTy',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLEC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STHP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STKP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STSTy',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STEC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_HPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPKP',modelJoint,'HighFiber');

load modelJoint_Enterocyte_HPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPSTy',modelJoint,'HighFiber');

load modelJoint_Enterocyte_HPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPEC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_HPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_HPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPSTy',modelJoint,'HighFiber');

load modelJoint_Enterocyte_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPEC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyEC',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECs',modelJoint,'HighFiber');

load modelJoint_Enterocyte_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECe',modelJoint,'HighFiber');

load modelJoint_Enterocyte_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECsECe',modelJoint,'HighFiber');


load FVASolutions.mat;
save FVASolutions_IEC_Microbes_HighFiber.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;


% Protein diet, with oxygen, with enterocyte
% calculate microbe growth when grown separately

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('FP',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BT',modelJoint,'Protein');

load modelJoint_Enterocyte_BTFP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FP',modelJoint,'Protein');

load modelJoint_Enterocyte_BTLP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LP',modelJoint,'Protein');

load modelJoint_Enterocyte_BTLL.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LL',modelJoint,'Protein');

load modelJoint_Enterocyte_BTST.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ST',modelJoint,'Protein');

load modelJoint_Enterocyte_BTHP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HP',modelJoint,'Protein');

load modelJoint_Enterocyte_BTKP.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KP',modelJoint,'Protein');

load modelJoint_Enterocyte_BTSTy.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STy',modelJoint,'Protein');

load modelJoint_Enterocyte_BTEC.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_EC',modelJoint,'Protein');

load modelJoint_Enterocyte_BTECs.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECs',modelJoint,'Protein');

load modelJoint_Enterocyte_BTECe.mat;
modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('BT',modelJoint.rxns)),0,'b');

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECe',modelJoint,'Protein');


% Protein diet, with oxygen, with enterocyte
% calculate microbe growth when grown pairwise in all combinations

load modelJoint_Enterocyte_BTFP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTFP',modelJoint,'Protein');

load modelJoint_Enterocyte_BTLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLP',modelJoint,'Protein');

load modelJoint_Enterocyte_BTLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTLL',modelJoint,'Protein');

load modelJoint_Enterocyte_BTST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTST',modelJoint,'Protein');

load modelJoint_Enterocyte_BTHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTHP',modelJoint,'Protein');

load modelJoint_Enterocyte_BTKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTKP',modelJoint,'Protein');

load modelJoint_Enterocyte_BTSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTSTy',modelJoint,'Protein');

load modelJoint_Enterocyte_BTEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTEC',modelJoint,'Protein');

load modelJoint_Enterocyte_BTECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECs',modelJoint,'Protein');

load modelJoint_Enterocyte_BTECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_BTECe',modelJoint,'Protein');

load modelJoint_Enterocyte_FPLP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLP',modelJoint,'Protein');

load modelJoint_Enterocyte_FPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPLL',modelJoint,'Protein');

load modelJoint_Enterocyte_FPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPST',modelJoint,'Protein');

load modelJoint_Enterocyte_FPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPHP',modelJoint,'Protein');

load modelJoint_Enterocyte_FPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPKP',modelJoint,'Protein');

load modelJoint_Enterocyte_FPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPSTy',modelJoint,'Protein');

load modelJoint_Enterocyte_FPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPEC',modelJoint,'Protein');

load modelJoint_Enterocyte_FPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECs',modelJoint,'Protein');

load modelJoint_Enterocyte_FPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_FPECe',modelJoint,'Protein');

load modelJoint_Enterocyte_LPLL.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPLL',modelJoint,'Protein');

load modelJoint_Enterocyte_LPST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPST',modelJoint,'Protein');

load modelJoint_Enterocyte_LPHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPHP',modelJoint,'Protein');

load modelJoint_Enterocyte_LPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPKP',modelJoint,'Protein');

load modelJoint_Enterocyte_LPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPSTy',modelJoint,'Protein');

load modelJoint_Enterocyte_LPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPEC',modelJoint,'Protein');

load modelJoint_Enterocyte_LPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECs',modelJoint,'Protein');

load modelJoint_Enterocyte_LPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LPECe',modelJoint,'Protein');

load modelJoint_Enterocyte_LLST.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLST',modelJoint,'Protein');

load modelJoint_Enterocyte_LLHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLHP',modelJoint,'Protein');

load modelJoint_Enterocyte_LLKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLKP',modelJoint,'Protein');

load modelJoint_Enterocyte_LLSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLSTy',modelJoint,'Protein');

load modelJoint_Enterocyte_LLEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLEC',modelJoint,'Protein');

load modelJoint_Enterocyte_LLECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECs',modelJoint,'Protein');

load modelJoint_Enterocyte_LLECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_LLECe',modelJoint,'Protein');

load modelJoint_Enterocyte_STHP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STHP',modelJoint,'Protein');

load modelJoint_Enterocyte_STKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STKP',modelJoint,'Protein');

load modelJoint_Enterocyte_STSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STSTy',modelJoint,'Protein');

load modelJoint_Enterocyte_STEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STEC',modelJoint,'Protein');

load modelJoint_Enterocyte_STECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECs',modelJoint,'Protein');

load modelJoint_Enterocyte_STECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STECe',modelJoint,'Protein');

load modelJoint_Enterocyte_HPKP.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPKP',modelJoint,'Protein');

load modelJoint_Enterocyte_HPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPSTy',modelJoint,'Protein');

load modelJoint_Enterocyte_HPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPEC',modelJoint,'Protein');

load modelJoint_Enterocyte_HPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPECs',modelJoint,'Protein');

load modelJoint_Enterocyte_HPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_HPECe',modelJoint,'Protein');

load modelJoint_Enterocyte_KPSTy.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPSTy',modelJoint,'Protein');

load modelJoint_Enterocyte_KPEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPEC',modelJoint,'Protein');

load modelJoint_Enterocyte_KPECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECs',modelJoint,'Protein');

load modelJoint_Enterocyte_KPECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_KPECe',modelJoint,'Protein');

load modelJoint_Enterocyte_STyEC.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyEC',modelJoint,'Protein');

load modelJoint_Enterocyte_STyECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECs',modelJoint,'Protein');

load modelJoint_Enterocyte_STyECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_STyECe',modelJoint,'Protein');

load modelJoint_Enterocyte_ECECs.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECs',modelJoint,'Protein');

load modelJoint_Enterocyte_ECECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECECe',modelJoint,'Protein');

load modelJoint_Enterocyte_ECsECe.mat;

[solution,minFlux,maxFlux]=calculateMicrobeGrowth('IEC_ECsECe',modelJoint,'Protein');

load FVASolutions.mat;
save FVASolutions_IEC_Microbes_Protein.mat FVASolutions;
FVASolutions=[];
save FVASolutions.mat FVASolutions;

% now sort the growth rates and interactions in one table
% results in Table S2 of the manuscript
load GrowthRates.mat;

PairwiseGrowth{1,1}='WesternDiet_NoOxygen';
PairwiseGrowth{1,2}='BT';
PairwiseGrowth{1,3}='FP';
PairwiseGrowth{1,4}='LP';
PairwiseGrowth{1,5}='LL';
PairwiseGrowth{1,6}='ST';
PairwiseGrowth{1,7}='HP';
PairwiseGrowth{1,8}='KP';
PairwiseGrowth{1,9}='STy';
PairwiseGrowth{1,10}='EC';
PairwiseGrowth{1,11}='ECs';
PairwiseGrowth{1,12}='ECe';
PairwiseGrowth{2,1}='Single';
PairwiseGrowth{3,1}='With_IEC';
PairwiseGrowth{4,1}='With_BT';
PairwiseGrowth{5,1}='With_FP';
PairwiseGrowth{6,1}='With_LP';
PairwiseGrowth{7,1}='With_LL';
PairwiseGrowth{8,1}='With_ST';
PairwiseGrowth{9,1}='With_KP';
PairwiseGrowth{10,1}='With_STy';
PairwiseGrowth{11,1}='With_EC';
PairwiseGrowth{12,1}='With_ECs';
PairwiseGrowth{13,1}='With_ECe';
PairwiseGrowth{14,1}='With_BT_IEC';
PairwiseGrowth{15,1}='With_FP_IEC';
PairwiseGrowth{16,1}='With_LP_IEC';
PairwiseGrowth{17,1}='With_LL_IEC';
PairwiseGrowth{18,1}='With_ST_IEC';
PairwiseGrowth{19,1}='With_KP_IEC';
PairwiseGrowth{20,1}='With_STy_IEC';
PairwiseGrowth{21,1}='With_EC_IEC';
PairwiseGrowth{22,1}='With_ECs_IEC';
PairwiseGrowth{23,1}='With_ECe_IEC';
PairwiseGrowth{24,1}='HighFiberDiet_NoOxygen';
PairwiseGrowth{24,2}='BT';
PairwiseGrowth{24,3}='FP';
PairwiseGrowth{24,4}='LP';
PairwiseGrowth{24,5}='LL';
PairwiseGrowth{24,6}='ST';
PairwiseGrowth{24,7}='HP';
PairwiseGrowth{24,8}='KP';
PairwiseGrowth{24,9}='STy';
PairwiseGrowth{24,10}='EC';
PairwiseGrowth{24,11}='ECs';
PairwiseGrowth{24,12}='ECe';
PairwiseGrowth{25,1}='Single';
PairwiseGrowth{26,1}='With_IEC';
PairwiseGrowth{27,1}='With_BT';
PairwiseGrowth{28,1}='With_FP';
PairwiseGrowth{29,1}='With_LP';
PairwiseGrowth{30,1}='With_LL';
PairwiseGrowth{31,1}='With_ST';
PairwiseGrowth{32,1}='With_KP';
PairwiseGrowth{33,1}='With_STy';
PairwiseGrowth{34,1}='With_EC';
PairwiseGrowth{35,1}='With_ECs';
PairwiseGrowth{36,1}='With_ECe';
PairwiseGrowth{37,1}='With_BT_IEC';
PairwiseGrowth{38,1}='With_FP_IEC';
PairwiseGrowth{39,1}='With_LP_IEC';
PairwiseGrowth{40,1}='With_LL_IEC';
PairwiseGrowth{41,1}='With_ST_IEC';
PairwiseGrowth{42,1}='With_KP_IEC';
PairwiseGrowth{43,1}='With_STy_IEC';
PairwiseGrowth{44,1}='With_EC_IEC';
PairwiseGrowth{45,1}='With_ECs_IEC';
PairwiseGrowth{46,1}='With_ECe_IEC';
PairwiseGrowth{47,1}='ProteinDiet_NoOxygen';
PairwiseGrowth{47,2}='BT';
PairwiseGrowth{47,3}='FP';
PairwiseGrowth{47,4}='LP';
PairwiseGrowth{47,5}='LL';
PairwiseGrowth{47,6}='ST';
PairwiseGrowth{47,7}='HP';
PairwiseGrowth{47,8}='KP';
PairwiseGrowth{47,9}='STy';
PairwiseGrowth{47,10}='EC';
PairwiseGrowth{47,11}='ECs';
PairwiseGrowth{47,12}='ECe';
PairwiseGrowth{48,1}='Single';
PairwiseGrowth{49,1}='With_IEC';
PairwiseGrowth{50,1}='With_BT';
PairwiseGrowth{51,1}='With_FP';
PairwiseGrowth{52,1}='With_LP';
PairwiseGrowth{53,1}='With_LL';
PairwiseGrowth{54,1}='With_ST';
PairwiseGrowth{55,1}='With_KP';
PairwiseGrowth{56,1}='With_STy';
PairwiseGrowth{57,1}='With_EC';
PairwiseGrowth{58,1}='With_ECs';
PairwiseGrowth{59,1}='With_ECe';
PairwiseGrowth{60,1}='With_BT_IEC';
PairwiseGrowth{61,1}='With_FP_IEC';
PairwiseGrowth{62,1}='With_LP_IEC';
PairwiseGrowth{63,1}='With_LL_IEC';
PairwiseGrowth{64,1}='With_ST_IEC';
PairwiseGrowth{65,1}='With_KP_IEC';
PairwiseGrowth{66,1}='With_STy_IEC';
PairwiseGrowth{67,1}='With_EC_IEC';
PairwiseGrowth{68,1}='With_ECs_IEC';
PairwiseGrowth{69,1}='With_ECe_IEC';
PairwiseGrowth{70,1}='WesternDiet_WithOxygen';
PairwiseGrowth{70,2}='BT';
PairwiseGrowth{70,3}='FP';
PairwiseGrowth{70,4}='LP';
PairwiseGrowth{70,5}='LL';
PairwiseGrowth{70,6}='ST';
PairwiseGrowth{70,7}='HP';
PairwiseGrowth{70,8}='KP';
PairwiseGrowth{70,9}='STy';
PairwiseGrowth{70,10}='EC';
PairwiseGrowth{70,11}='ECs';
PairwiseGrowth{70,12}='ECe';
PairwiseGrowth{71,1}='Single';
PairwiseGrowth{72,1}='With_IEC';
PairwiseGrowth{73,1}='With_BT';
PairwiseGrowth{74,1}='With_FP';
PairwiseGrowth{75,1}='With_LP';
PairwiseGrowth{76,1}='With_LL';
PairwiseGrowth{77,1}='With_ST';
PairwiseGrowth{78,1}='With_HP';
PairwiseGrowth{79,1}='With_KP';
PairwiseGrowth{80,1}='With_STy';
PairwiseGrowth{81,1}='With_EC';
PairwiseGrowth{82,1}='With_ECs';
PairwiseGrowth{83,1}='With_ECe';
PairwiseGrowth{84,1}='With_BT_IEC';
PairwiseGrowth{85,1}='With_FP_IEC';
PairwiseGrowth{86,1}='With_LP_IEC';
PairwiseGrowth{87,1}='With_LL_IEC';
PairwiseGrowth{88,1}='With_ST_IEC';
PairwiseGrowth{89,1}='With_HP_IEC';
PairwiseGrowth{90,1}='With_KP_IEC';
PairwiseGrowth{91,1}='With_STy_IEC';
PairwiseGrowth{92,1}='With_EC_IEC';
PairwiseGrowth{93,1}='With_ECs_IEC';
PairwiseGrowth{94,1}='With_ECe_IEC';
PairwiseGrowth{95,1}='HighFiberDiet_WithOxygen';
PairwiseGrowth{95,2}='BT';
PairwiseGrowth{95,3}='FP';
PairwiseGrowth{95,4}='LP';
PairwiseGrowth{95,5}='LL';
PairwiseGrowth{95,6}='ST';
PairwiseGrowth{95,7}='HP';
PairwiseGrowth{95,8}='KP';
PairwiseGrowth{95,9}='STy';
PairwiseGrowth{95,10}='EC';
PairwiseGrowth{95,11}='ECs';
PairwiseGrowth{95,12}='ECe';
PairwiseGrowth{96,1}='Single';
PairwiseGrowth{97,1}='With_IEC';
PairwiseGrowth{98,1}='With_BT';
PairwiseGrowth{99,1}='With_FP';
PairwiseGrowth{100,1}='With_LP';
PairwiseGrowth{101,1}='With_LL';
PairwiseGrowth{102,1}='With_ST';
PairwiseGrowth{103,1}='With_HP';
PairwiseGrowth{104,1}='With_KP';
PairwiseGrowth{105,1}='With_STy';
PairwiseGrowth{106,1}='With_EC';
PairwiseGrowth{107,1}='With_ECs';
PairwiseGrowth{108,1}='With_ECe';
PairwiseGrowth{109,1}='With_BT_IEC';
PairwiseGrowth{110,1}='With_FP_IEC';
PairwiseGrowth{111,1}='With_LP_IEC';
PairwiseGrowth{112,1}='With_LL_IEC';
PairwiseGrowth{113,1}='With_ST_IEC';
PairwiseGrowth{114,1}='With_HP_IEC';
PairwiseGrowth{115,1}='With_KP_IEC';
PairwiseGrowth{116,1}='With_STy_IEC';
PairwiseGrowth{117,1}='With_EC_IEC';
PairwiseGrowth{118,1}='With_ECs_IEC';
PairwiseGrowth{119,1}='With_ECe_IEC';
PairwiseGrowth{120,1}='ProteinDiet_WithOxygen';
PairwiseGrowth{120,2}='BT';
PairwiseGrowth{120,3}='FP';
PairwiseGrowth{120,4}='LP';
PairwiseGrowth{120,5}='LL';
PairwiseGrowth{120,6}='ST';
PairwiseGrowth{120,7}='HP';
PairwiseGrowth{120,8}='KP';
PairwiseGrowth{120,9}='STy';
PairwiseGrowth{120,10}='EC';
PairwiseGrowth{120,11}='ECs';
PairwiseGrowth{120,12}='ECe';
PairwiseGrowth{121,1}='Single';
PairwiseGrowth{122,1}='With_IEC';
PairwiseGrowth{123,1}='With_BT';
PairwiseGrowth{124,1}='With_FP';
PairwiseGrowth{125,1}='With_LP';
PairwiseGrowth{126,1}='With_LL';
PairwiseGrowth{127,1}='With_ST';
PairwiseGrowth{128,1}='With_HP';
PairwiseGrowth{129,1}='With_KP';
PairwiseGrowth{130,1}='With_STy';
PairwiseGrowth{131,1}='With_EC';
PairwiseGrowth{132,1}='With_ECs';
PairwiseGrowth{133,1}='With_ECe';
PairwiseGrowth{134,1}='With_BT_IEC';
PairwiseGrowth{135,1}='With_FP_IEC';
PairwiseGrowth{136,1}='With_LP_IEC';
PairwiseGrowth{137,1}='With_LL_IEC';
PairwiseGrowth{138,1}='With_ST_IEC';
PairwiseGrowth{139,1}='With_HP_IEC';
PairwiseGrowth{140,1}='With_KP_IEC';
PairwiseGrowth{141,1}='With_STy_IEC';
PairwiseGrowth{142,1}='With_EC_IEC';
PairwiseGrowth{143,1}='With_ECs_IEC';
PairwiseGrowth{144,1}='With_ECe_IEC';

PairwiseGrowth{2,2}=GrowthRates.WesternNoOx{2,2};
PairwiseGrowth{2,3}=GrowthRates.WesternNoOx{3,3};
PairwiseGrowth{2,4}=GrowthRates.WesternNoOx{4,4};
PairwiseGrowth{2,5}=GrowthRates.WesternNoOx{5,5};
PairwiseGrowth{2,6}=GrowthRates.WesternNoOx{6,6};
PairwiseGrowth{2,8}=GrowthRates.WesternNoOx{7,8};
PairwiseGrowth{2,9}=GrowthRates.WesternNoOx{8,9};
PairwiseGrowth{2,10}=GrowthRates.WesternNoOx{9,10};
PairwiseGrowth{2,11}=GrowthRates.WesternNoOx{10,11};
PairwiseGrowth{2,12}=GrowthRates.WesternNoOx{11,12};
PairwiseGrowth{3,2}=GrowthRates.WesternNoOx{57,2};
PairwiseGrowth{3,3}=GrowthRates.WesternNoOx{58,3};
PairwiseGrowth{3,4}=GrowthRates.WesternNoOx{59,4};
PairwiseGrowth{3,5}=GrowthRates.WesternNoOx{60,5};
PairwiseGrowth{3,6}=GrowthRates.WesternNoOx{61,6};
PairwiseGrowth{3,8}=GrowthRates.WesternNoOx{62,8};
PairwiseGrowth{3,9}=GrowthRates.WesternNoOx{63,9};
PairwiseGrowth{3,10}=GrowthRates.WesternNoOx{64,10};
PairwiseGrowth{3,11}=GrowthRates.WesternNoOx{65,11};
PairwiseGrowth{3,12}=GrowthRates.WesternNoOx{66,12};
PairwiseGrowth{4,3}=GrowthRates.WesternNoOx{12,3};
PairwiseGrowth{4,4}=GrowthRates.WesternNoOx{13,4};
PairwiseGrowth{4,5}=GrowthRates.WesternNoOx{14,5};
PairwiseGrowth{4,6}=GrowthRates.WesternNoOx{15,6};
PairwiseGrowth{4,8}=GrowthRates.WesternNoOx{16,8};
PairwiseGrowth{4,9}=GrowthRates.WesternNoOx{17,9};
PairwiseGrowth{4,10}=GrowthRates.WesternNoOx{18,10};
PairwiseGrowth{4,11}=GrowthRates.WesternNoOx{19,11};
PairwiseGrowth{4,12}=GrowthRates.WesternNoOx{20,12};
PairwiseGrowth{5,2}=GrowthRates.WesternNoOx{12,2};
PairwiseGrowth{5,4}=GrowthRates.WesternNoOx{21,4};
PairwiseGrowth{5,5}=GrowthRates.WesternNoOx{22,5};
PairwiseGrowth{5,6}=GrowthRates.WesternNoOx{23,6};
PairwiseGrowth{5,8}=GrowthRates.WesternNoOx{24,8};
PairwiseGrowth{5,9}=GrowthRates.WesternNoOx{25,9};
PairwiseGrowth{5,10}=GrowthRates.WesternNoOx{26,10};
PairwiseGrowth{5,11}=GrowthRates.WesternNoOx{27,11};
PairwiseGrowth{5,12}=GrowthRates.WesternNoOx{28,12};
PairwiseGrowth{6,2}=GrowthRates.WesternNoOx{13,2};
PairwiseGrowth{6,3}=GrowthRates.WesternNoOx{21,3};
PairwiseGrowth{6,5}=GrowthRates.WesternNoOx{29,5};
PairwiseGrowth{6,6}=GrowthRates.WesternNoOx{30,6};
PairwiseGrowth{6,8}=GrowthRates.WesternNoOx{31,8};
PairwiseGrowth{6,9}=GrowthRates.WesternNoOx{32,9};
PairwiseGrowth{6,10}=GrowthRates.WesternNoOx{33,10};
PairwiseGrowth{6,11}=GrowthRates.WesternNoOx{34,11};
PairwiseGrowth{6,12}=GrowthRates.WesternNoOx{35,12};
PairwiseGrowth{7,2}=GrowthRates.WesternNoOx{14,2};
PairwiseGrowth{7,3}=GrowthRates.WesternNoOx{22,3};
PairwiseGrowth{7,4}=GrowthRates.WesternNoOx{29,4};
PairwiseGrowth{7,6}=GrowthRates.WesternNoOx{36,6};
PairwiseGrowth{7,8}=GrowthRates.WesternNoOx{37,8};
PairwiseGrowth{7,9}=GrowthRates.WesternNoOx{38,9};
PairwiseGrowth{7,10}=GrowthRates.WesternNoOx{39,10};
PairwiseGrowth{7,11}=GrowthRates.WesternNoOx{40,11};
PairwiseGrowth{7,12}=GrowthRates.WesternNoOx{41,12};
PairwiseGrowth{8,2}=GrowthRates.WesternNoOx{15,2};
PairwiseGrowth{8,3}=GrowthRates.WesternNoOx{23,3};
PairwiseGrowth{8,4}=GrowthRates.WesternNoOx{30,4};
PairwiseGrowth{8,5}=GrowthRates.WesternNoOx{36,5};
PairwiseGrowth{8,8}=GrowthRates.WesternNoOx{42,8};
PairwiseGrowth{8,9}=GrowthRates.WesternNoOx{43,9};
PairwiseGrowth{8,10}=GrowthRates.WesternNoOx{44,10};
PairwiseGrowth{8,11}=GrowthRates.WesternNoOx{45,11};
PairwiseGrowth{8,12}=GrowthRates.WesternNoOx{46,12};
PairwiseGrowth{9,2}=GrowthRates.WesternNoOx{16,2};
PairwiseGrowth{9,3}=GrowthRates.WesternNoOx{24,3};
PairwiseGrowth{9,4}=GrowthRates.WesternNoOx{31,4};
PairwiseGrowth{9,5}=GrowthRates.WesternNoOx{37,5};
PairwiseGrowth{9,6}=GrowthRates.WesternNoOx{42,6};
PairwiseGrowth{9,9}=GrowthRates.WesternNoOx{47,9};
PairwiseGrowth{9,10}=GrowthRates.WesternNoOx{48,10};
PairwiseGrowth{9,11}=GrowthRates.WesternNoOx{49,11};
PairwiseGrowth{9,12}=GrowthRates.WesternNoOx{50,12};
PairwiseGrowth{10,2}=GrowthRates.WesternNoOx{17,2};
PairwiseGrowth{10,3}=GrowthRates.WesternNoOx{25,3};
PairwiseGrowth{10,4}=GrowthRates.WesternNoOx{32,4};
PairwiseGrowth{10,5}=GrowthRates.WesternNoOx{38,5};
PairwiseGrowth{10,6}=GrowthRates.WesternNoOx{43,6};
PairwiseGrowth{10,8}=GrowthRates.WesternNoOx{47,8};
PairwiseGrowth{10,10}=GrowthRates.WesternNoOx{51,10};
PairwiseGrowth{10,11}=GrowthRates.WesternNoOx{52,11};
PairwiseGrowth{10,12}=GrowthRates.WesternNoOx{53,12};
PairwiseGrowth{11,2}=GrowthRates.WesternNoOx{18,2};
PairwiseGrowth{11,3}=GrowthRates.WesternNoOx{26,3};
PairwiseGrowth{11,4}=GrowthRates.WesternNoOx{33,4};
PairwiseGrowth{11,5}=GrowthRates.WesternNoOx{39,5};
PairwiseGrowth{11,6}=GrowthRates.WesternNoOx{44,6};
PairwiseGrowth{11,8}=GrowthRates.WesternNoOx{48,8};
PairwiseGrowth{11,9}=GrowthRates.WesternNoOx{51,9};
PairwiseGrowth{11,11}=GrowthRates.WesternNoOx{54,11};
PairwiseGrowth{11,12}=GrowthRates.WesternNoOx{55,12};
PairwiseGrowth{12,2}=GrowthRates.WesternNoOx{19,2};
PairwiseGrowth{12,3}=GrowthRates.WesternNoOx{27,3};
PairwiseGrowth{12,4}=GrowthRates.WesternNoOx{34,4};
PairwiseGrowth{12,5}=GrowthRates.WesternNoOx{40,5};
PairwiseGrowth{12,6}=GrowthRates.WesternNoOx{45,6};
PairwiseGrowth{12,8}=GrowthRates.WesternNoOx{49,8};
PairwiseGrowth{12,9}=GrowthRates.WesternNoOx{52,9};
PairwiseGrowth{12,10}=GrowthRates.WesternNoOx{54,10};
PairwiseGrowth{12,12}=GrowthRates.WesternNoOx{56,12};
PairwiseGrowth{13,2}=GrowthRates.WesternNoOx{20,2};
PairwiseGrowth{13,3}=GrowthRates.WesternNoOx{28,3};
PairwiseGrowth{13,4}=GrowthRates.WesternNoOx{35,4};
PairwiseGrowth{13,5}=GrowthRates.WesternNoOx{41,5};
PairwiseGrowth{13,6}=GrowthRates.WesternNoOx{46,6};
PairwiseGrowth{13,8}=GrowthRates.WesternNoOx{50,8};
PairwiseGrowth{13,9}=GrowthRates.WesternNoOx{53,9};
PairwiseGrowth{13,10}=GrowthRates.WesternNoOx{55,10};
PairwiseGrowth{13,11}=GrowthRates.WesternNoOx{56,11};

PairwiseGrowth{14,3}=GrowthRates.WesternNoOx{67,3};
PairwiseGrowth{14,4}=GrowthRates.WesternNoOx{68,4};
PairwiseGrowth{14,5}=GrowthRates.WesternNoOx{69,5};
PairwiseGrowth{14,6}=GrowthRates.WesternNoOx{70,6};
PairwiseGrowth{14,8}=GrowthRates.WesternNoOx{71,8};
PairwiseGrowth{14,9}=GrowthRates.WesternNoOx{72,9};
PairwiseGrowth{14,10}=GrowthRates.WesternNoOx{73,10};
PairwiseGrowth{14,11}=GrowthRates.WesternNoOx{74,11};
PairwiseGrowth{14,12}=GrowthRates.WesternNoOx{75,12};
PairwiseGrowth{15,2}=GrowthRates.WesternNoOx{67,2};
PairwiseGrowth{15,4}=GrowthRates.WesternNoOx{76,4};
PairwiseGrowth{15,5}=GrowthRates.WesternNoOx{77,5};
PairwiseGrowth{15,6}=GrowthRates.WesternNoOx{78,6};
PairwiseGrowth{15,8}=GrowthRates.WesternNoOx{79,8};
PairwiseGrowth{15,9}=GrowthRates.WesternNoOx{80,9};
PairwiseGrowth{15,10}=GrowthRates.WesternNoOx{81,10};
PairwiseGrowth{15,11}=GrowthRates.WesternNoOx{82,11};
PairwiseGrowth{15,12}=GrowthRates.WesternNoOx{83,12};
PairwiseGrowth{16,2}=GrowthRates.WesternNoOx{68,2};
PairwiseGrowth{16,3}=GrowthRates.WesternNoOx{76,3};
PairwiseGrowth{16,5}=GrowthRates.WesternNoOx{84,5};
PairwiseGrowth{16,6}=GrowthRates.WesternNoOx{85,6};
PairwiseGrowth{16,8}=GrowthRates.WesternNoOx{86,8};
PairwiseGrowth{16,9}=GrowthRates.WesternNoOx{87,9};
PairwiseGrowth{16,10}=GrowthRates.WesternNoOx{88,10};
PairwiseGrowth{16,11}=GrowthRates.WesternNoOx{89,11};
PairwiseGrowth{16,12}=GrowthRates.WesternNoOx{90,12};
PairwiseGrowth{17,2}=GrowthRates.WesternNoOx{69,2};
PairwiseGrowth{17,3}=GrowthRates.WesternNoOx{77,3};
PairwiseGrowth{17,4}=GrowthRates.WesternNoOx{84,4};
PairwiseGrowth{17,6}=GrowthRates.WesternNoOx{91,6};
PairwiseGrowth{17,8}=GrowthRates.WesternNoOx{92,8};
PairwiseGrowth{17,9}=GrowthRates.WesternNoOx{93,9};
PairwiseGrowth{17,10}=GrowthRates.WesternNoOx{94,10};
PairwiseGrowth{17,11}=GrowthRates.WesternNoOx{95,11};
PairwiseGrowth{17,12}=GrowthRates.WesternNoOx{96,12};
PairwiseGrowth{18,2}=GrowthRates.WesternNoOx{70,2};
PairwiseGrowth{18,3}=GrowthRates.WesternNoOx{78,3};
PairwiseGrowth{18,4}=GrowthRates.WesternNoOx{85,4};
PairwiseGrowth{18,5}=GrowthRates.WesternNoOx{91,5};
PairwiseGrowth{18,8}=GrowthRates.WesternNoOx{97,8};
PairwiseGrowth{18,9}=GrowthRates.WesternNoOx{98,9};
PairwiseGrowth{18,10}=GrowthRates.WesternNoOx{99,10};
PairwiseGrowth{18,11}=GrowthRates.WesternNoOx{100,11};
PairwiseGrowth{18,12}=GrowthRates.WesternNoOx{101,12};
PairwiseGrowth{19,2}=GrowthRates.WesternNoOx{71,2};
PairwiseGrowth{19,3}=GrowthRates.WesternNoOx{79,3};
PairwiseGrowth{19,4}=GrowthRates.WesternNoOx{31,4};
PairwiseGrowth{19,5}=GrowthRates.WesternNoOx{92,5};
PairwiseGrowth{19,6}=GrowthRates.WesternNoOx{97,6};
PairwiseGrowth{19,9}=GrowthRates.WesternNoOx{102,9};
PairwiseGrowth{19,10}=GrowthRates.WesternNoOx{103,10};
PairwiseGrowth{19,11}=GrowthRates.WesternNoOx{104,11};
PairwiseGrowth{19,12}=GrowthRates.WesternNoOx{105,12};
PairwiseGrowth{20,2}=GrowthRates.WesternNoOx{72,2};
PairwiseGrowth{20,3}=GrowthRates.WesternNoOx{80,3};
PairwiseGrowth{20,4}=GrowthRates.WesternNoOx{87,4};
PairwiseGrowth{20,5}=GrowthRates.WesternNoOx{93,5};
PairwiseGrowth{20,6}=GrowthRates.WesternNoOx{98,6};
PairwiseGrowth{20,8}=GrowthRates.WesternNoOx{102,8};
PairwiseGrowth{20,10}=GrowthRates.WesternNoOx{106,10};
PairwiseGrowth{20,11}=GrowthRates.WesternNoOx{107,11};
PairwiseGrowth{20,12}=GrowthRates.WesternNoOx{108,12};
PairwiseGrowth{21,2}=GrowthRates.WesternNoOx{73,2};
PairwiseGrowth{21,3}=GrowthRates.WesternNoOx{81,3};
PairwiseGrowth{21,4}=GrowthRates.WesternNoOx{88,4};
PairwiseGrowth{21,5}=GrowthRates.WesternNoOx{94,5};
PairwiseGrowth{21,6}=GrowthRates.WesternNoOx{99,6};
PairwiseGrowth{21,8}=GrowthRates.WesternNoOx{103,8};
PairwiseGrowth{21,9}=GrowthRates.WesternNoOx{106,9};
PairwiseGrowth{21,11}=GrowthRates.WesternNoOx{109,11};
PairwiseGrowth{21,12}=GrowthRates.WesternNoOx{110,12};
PairwiseGrowth{22,2}=GrowthRates.WesternNoOx{74,2};
PairwiseGrowth{22,3}=GrowthRates.WesternNoOx{82,3};
PairwiseGrowth{22,4}=GrowthRates.WesternNoOx{89,4};
PairwiseGrowth{22,5}=GrowthRates.WesternNoOx{95,5};
PairwiseGrowth{22,6}=GrowthRates.WesternNoOx{100,6};
PairwiseGrowth{22,8}=GrowthRates.WesternNoOx{104,8};
PairwiseGrowth{22,9}=GrowthRates.WesternNoOx{107,9};
PairwiseGrowth{22,10}=GrowthRates.WesternNoOx{109,10};
PairwiseGrowth{22,12}=GrowthRates.WesternNoOx{111,12};
PairwiseGrowth{23,2}=GrowthRates.WesternNoOx{75,2};
PairwiseGrowth{23,3}=GrowthRates.WesternNoOx{83,3};
PairwiseGrowth{23,4}=GrowthRates.WesternNoOx{90,4};
PairwiseGrowth{23,5}=GrowthRates.WesternNoOx{96,5};
PairwiseGrowth{23,6}=GrowthRates.WesternNoOx{101,6};
PairwiseGrowth{23,8}=GrowthRates.WesternNoOx{105,8};
PairwiseGrowth{23,9}=GrowthRates.WesternNoOx{108,9};
PairwiseGrowth{23,10}=GrowthRates.WesternNoOx{110,10};
PairwiseGrowth{23,11}=GrowthRates.WesternNoOx{111,11};

PairwiseGrowth{25,2}=GrowthRates.HighFiberNoOx{2,2};
PairwiseGrowth{25,3}=GrowthRates.HighFiberNoOx{3,3};
PairwiseGrowth{25,4}=GrowthRates.HighFiberNoOx{4,4};
PairwiseGrowth{25,5}=GrowthRates.HighFiberNoOx{5,5};
PairwiseGrowth{25,6}=GrowthRates.HighFiberNoOx{6,6};
PairwiseGrowth{25,8}=GrowthRates.HighFiberNoOx{7,8};
PairwiseGrowth{25,9}=GrowthRates.HighFiberNoOx{8,9};
PairwiseGrowth{25,10}=GrowthRates.HighFiberNoOx{9,10};
PairwiseGrowth{25,11}=GrowthRates.HighFiberNoOx{10,11};
PairwiseGrowth{25,12}=GrowthRates.HighFiberNoOx{11,12};
PairwiseGrowth{26,2}=GrowthRates.HighFiberNoOx{57,2};
PairwiseGrowth{26,3}=GrowthRates.HighFiberNoOx{58,3};
PairwiseGrowth{26,4}=GrowthRates.HighFiberNoOx{59,4};
PairwiseGrowth{26,5}=GrowthRates.HighFiberNoOx{60,5};
PairwiseGrowth{26,6}=GrowthRates.HighFiberNoOx{61,6};
PairwiseGrowth{26,8}=GrowthRates.HighFiberNoOx{62,8};
PairwiseGrowth{26,9}=GrowthRates.HighFiberNoOx{63,9};
PairwiseGrowth{26,10}=GrowthRates.HighFiberNoOx{64,10};
PairwiseGrowth{26,11}=GrowthRates.HighFiberNoOx{65,11};
PairwiseGrowth{26,12}=GrowthRates.HighFiberNoOx{66,12};
PairwiseGrowth{27,3}=GrowthRates.HighFiberNoOx{12,3};
PairwiseGrowth{27,4}=GrowthRates.HighFiberNoOx{13,4};
PairwiseGrowth{27,5}=GrowthRates.HighFiberNoOx{14,5};
PairwiseGrowth{27,6}=GrowthRates.HighFiberNoOx{15,6};
PairwiseGrowth{27,8}=GrowthRates.HighFiberNoOx{16,8};
PairwiseGrowth{27,9}=GrowthRates.HighFiberNoOx{17,9};
PairwiseGrowth{27,10}=GrowthRates.HighFiberNoOx{18,10};
PairwiseGrowth{27,11}=GrowthRates.HighFiberNoOx{19,11};
PairwiseGrowth{27,12}=GrowthRates.HighFiberNoOx{20,12};
PairwiseGrowth{28,2}=GrowthRates.HighFiberNoOx{12,2};
PairwiseGrowth{28,4}=GrowthRates.HighFiberNoOx{21,4};
PairwiseGrowth{28,5}=GrowthRates.HighFiberNoOx{22,5};
PairwiseGrowth{28,6}=GrowthRates.HighFiberNoOx{23,6};
PairwiseGrowth{28,8}=GrowthRates.HighFiberNoOx{24,8};
PairwiseGrowth{28,9}=GrowthRates.HighFiberNoOx{25,9};
PairwiseGrowth{28,10}=GrowthRates.HighFiberNoOx{26,10};
PairwiseGrowth{28,11}=GrowthRates.HighFiberNoOx{27,11};
PairwiseGrowth{28,12}=GrowthRates.HighFiberNoOx{28,12};
PairwiseGrowth{29,2}=GrowthRates.HighFiberNoOx{13,2};
PairwiseGrowth{29,3}=GrowthRates.HighFiberNoOx{21,3};
PairwiseGrowth{29,5}=GrowthRates.HighFiberNoOx{29,5};
PairwiseGrowth{29,6}=GrowthRates.HighFiberNoOx{30,6};
PairwiseGrowth{29,8}=GrowthRates.HighFiberNoOx{31,8};
PairwiseGrowth{29,9}=GrowthRates.HighFiberNoOx{32,9};
PairwiseGrowth{29,10}=GrowthRates.HighFiberNoOx{33,10};
PairwiseGrowth{29,11}=GrowthRates.HighFiberNoOx{34,11};
PairwiseGrowth{29,12}=GrowthRates.HighFiberNoOx{35,12};
PairwiseGrowth{30,2}=GrowthRates.HighFiberNoOx{14,2};
PairwiseGrowth{30,3}=GrowthRates.HighFiberNoOx{22,3};
PairwiseGrowth{30,4}=GrowthRates.HighFiberNoOx{29,4};
PairwiseGrowth{30,6}=GrowthRates.HighFiberNoOx{36,6};
PairwiseGrowth{30,8}=GrowthRates.HighFiberNoOx{37,8};
PairwiseGrowth{30,9}=GrowthRates.HighFiberNoOx{38,9};
PairwiseGrowth{30,10}=GrowthRates.HighFiberNoOx{39,10};
PairwiseGrowth{30,11}=GrowthRates.HighFiberNoOx{40,11};
PairwiseGrowth{30,12}=GrowthRates.HighFiberNoOx{41,12};
PairwiseGrowth{31,2}=GrowthRates.HighFiberNoOx{15,2};
PairwiseGrowth{31,3}=GrowthRates.HighFiberNoOx{23,3};
PairwiseGrowth{31,4}=GrowthRates.HighFiberNoOx{30,4};
PairwiseGrowth{31,5}=GrowthRates.HighFiberNoOx{36,5};
PairwiseGrowth{31,8}=GrowthRates.HighFiberNoOx{42,8};
PairwiseGrowth{31,9}=GrowthRates.HighFiberNoOx{43,9};
PairwiseGrowth{31,10}=GrowthRates.HighFiberNoOx{44,10};
PairwiseGrowth{31,11}=GrowthRates.HighFiberNoOx{45,11};
PairwiseGrowth{31,12}=GrowthRates.HighFiberNoOx{46,12};
PairwiseGrowth{32,2}=GrowthRates.HighFiberNoOx{16,2};
PairwiseGrowth{32,3}=GrowthRates.HighFiberNoOx{24,3};
PairwiseGrowth{32,4}=GrowthRates.HighFiberNoOx{31,4};
PairwiseGrowth{32,5}=GrowthRates.HighFiberNoOx{37,5};
PairwiseGrowth{32,6}=GrowthRates.HighFiberNoOx{42,6};
PairwiseGrowth{32,9}=GrowthRates.HighFiberNoOx{47,9};
PairwiseGrowth{32,10}=GrowthRates.HighFiberNoOx{48,10};
PairwiseGrowth{32,11}=GrowthRates.HighFiberNoOx{49,11};
PairwiseGrowth{32,12}=GrowthRates.HighFiberNoOx{50,12};
PairwiseGrowth{33,2}=GrowthRates.HighFiberNoOx{17,2};
PairwiseGrowth{33,3}=GrowthRates.HighFiberNoOx{25,3};
PairwiseGrowth{33,4}=GrowthRates.HighFiberNoOx{32,4};
PairwiseGrowth{33,5}=GrowthRates.HighFiberNoOx{38,5};
PairwiseGrowth{33,6}=GrowthRates.HighFiberNoOx{43,6};
PairwiseGrowth{33,8}=GrowthRates.HighFiberNoOx{47,8};
PairwiseGrowth{33,10}=GrowthRates.HighFiberNoOx{51,10};
PairwiseGrowth{33,11}=GrowthRates.HighFiberNoOx{52,11};
PairwiseGrowth{33,12}=GrowthRates.HighFiberNoOx{53,12};
PairwiseGrowth{34,2}=GrowthRates.HighFiberNoOx{18,2};
PairwiseGrowth{34,3}=GrowthRates.HighFiberNoOx{26,3};
PairwiseGrowth{34,4}=GrowthRates.HighFiberNoOx{33,4};
PairwiseGrowth{34,5}=GrowthRates.HighFiberNoOx{39,5};
PairwiseGrowth{34,6}=GrowthRates.HighFiberNoOx{44,6};
PairwiseGrowth{34,8}=GrowthRates.HighFiberNoOx{48,8};
PairwiseGrowth{34,9}=GrowthRates.HighFiberNoOx{51,9};
PairwiseGrowth{34,11}=GrowthRates.HighFiberNoOx{54,11};
PairwiseGrowth{34,12}=GrowthRates.HighFiberNoOx{55,12};
PairwiseGrowth{35,2}=GrowthRates.HighFiberNoOx{19,2};
PairwiseGrowth{35,3}=GrowthRates.HighFiberNoOx{27,3};
PairwiseGrowth{35,4}=GrowthRates.HighFiberNoOx{34,4};
PairwiseGrowth{35,5}=GrowthRates.HighFiberNoOx{40,5};
PairwiseGrowth{35,6}=GrowthRates.HighFiberNoOx{45,6};
PairwiseGrowth{35,8}=GrowthRates.HighFiberNoOx{49,8};
PairwiseGrowth{35,9}=GrowthRates.HighFiberNoOx{52,9};
PairwiseGrowth{35,10}=GrowthRates.HighFiberNoOx{54,10};
PairwiseGrowth{35,12}=GrowthRates.HighFiberNoOx{56,12};
PairwiseGrowth{36,2}=GrowthRates.HighFiberNoOx{20,2};
PairwiseGrowth{36,3}=GrowthRates.HighFiberNoOx{28,3};
PairwiseGrowth{36,4}=GrowthRates.HighFiberNoOx{35,4};
PairwiseGrowth{36,5}=GrowthRates.HighFiberNoOx{41,5};
PairwiseGrowth{36,6}=GrowthRates.HighFiberNoOx{46,6};
PairwiseGrowth{36,8}=GrowthRates.HighFiberNoOx{50,8};
PairwiseGrowth{36,9}=GrowthRates.HighFiberNoOx{53,9};
PairwiseGrowth{36,10}=GrowthRates.HighFiberNoOx{55,10};
PairwiseGrowth{36,11}=GrowthRates.HighFiberNoOx{56,11};

PairwiseGrowth{37,3}=GrowthRates.HighFiberNoOx{67,3};
PairwiseGrowth{37,4}=GrowthRates.HighFiberNoOx{68,4};
PairwiseGrowth{37,5}=GrowthRates.HighFiberNoOx{69,5};
PairwiseGrowth{37,6}=GrowthRates.HighFiberNoOx{70,6};
PairwiseGrowth{37,8}=GrowthRates.HighFiberNoOx{71,8};
PairwiseGrowth{37,9}=GrowthRates.HighFiberNoOx{72,9};
PairwiseGrowth{37,10}=GrowthRates.HighFiberNoOx{73,10};
PairwiseGrowth{37,11}=GrowthRates.HighFiberNoOx{74,11};
PairwiseGrowth{37,12}=GrowthRates.HighFiberNoOx{75,12};
PairwiseGrowth{38,2}=GrowthRates.HighFiberNoOx{67,2};
PairwiseGrowth{38,4}=GrowthRates.HighFiberNoOx{76,4};
PairwiseGrowth{38,5}=GrowthRates.HighFiberNoOx{77,5};
PairwiseGrowth{38,6}=GrowthRates.HighFiberNoOx{78,6};
PairwiseGrowth{38,8}=GrowthRates.HighFiberNoOx{79,8};
PairwiseGrowth{38,9}=GrowthRates.HighFiberNoOx{80,9};
PairwiseGrowth{38,10}=GrowthRates.HighFiberNoOx{81,10};
PairwiseGrowth{38,11}=GrowthRates.HighFiberNoOx{82,11};
PairwiseGrowth{38,12}=GrowthRates.HighFiberNoOx{83,12};
PairwiseGrowth{39,2}=GrowthRates.HighFiberNoOx{68,2};
PairwiseGrowth{39,3}=GrowthRates.HighFiberNoOx{76,3};
PairwiseGrowth{39,5}=GrowthRates.HighFiberNoOx{84,5};
PairwiseGrowth{39,6}=GrowthRates.HighFiberNoOx{85,6};
PairwiseGrowth{39,8}=GrowthRates.HighFiberNoOx{86,8};
PairwiseGrowth{39,9}=GrowthRates.HighFiberNoOx{87,9};
PairwiseGrowth{39,10}=GrowthRates.HighFiberNoOx{88,10};
PairwiseGrowth{39,11}=GrowthRates.HighFiberNoOx{89,11};
PairwiseGrowth{39,12}=GrowthRates.HighFiberNoOx{90,12};
PairwiseGrowth{40,2}=GrowthRates.HighFiberNoOx{69,2};
PairwiseGrowth{40,3}=GrowthRates.HighFiberNoOx{77,3};
PairwiseGrowth{40,4}=GrowthRates.HighFiberNoOx{84,4};
PairwiseGrowth{40,6}=GrowthRates.HighFiberNoOx{91,6};
PairwiseGrowth{40,8}=GrowthRates.HighFiberNoOx{92,8};
PairwiseGrowth{40,9}=GrowthRates.HighFiberNoOx{93,9};
PairwiseGrowth{40,10}=GrowthRates.HighFiberNoOx{94,10};
PairwiseGrowth{40,11}=GrowthRates.HighFiberNoOx{95,11};
PairwiseGrowth{40,12}=GrowthRates.HighFiberNoOx{96,12};
PairwiseGrowth{41,2}=GrowthRates.HighFiberNoOx{70,2};
PairwiseGrowth{41,3}=GrowthRates.HighFiberNoOx{78,3};
PairwiseGrowth{41,4}=GrowthRates.HighFiberNoOx{85,4};
PairwiseGrowth{41,5}=GrowthRates.HighFiberNoOx{91,5};
PairwiseGrowth{41,8}=GrowthRates.HighFiberNoOx{97,8};
PairwiseGrowth{41,9}=GrowthRates.HighFiberNoOx{98,9};
PairwiseGrowth{41,10}=GrowthRates.HighFiberNoOx{99,10};
PairwiseGrowth{41,11}=GrowthRates.HighFiberNoOx{100,11};
PairwiseGrowth{41,12}=GrowthRates.HighFiberNoOx{101,12};
PairwiseGrowth{42,2}=GrowthRates.HighFiberNoOx{71,2};
PairwiseGrowth{42,3}=GrowthRates.HighFiberNoOx{79,3};
PairwiseGrowth{42,4}=GrowthRates.HighFiberNoOx{31,4};
PairwiseGrowth{42,5}=GrowthRates.HighFiberNoOx{92,5};
PairwiseGrowth{42,6}=GrowthRates.HighFiberNoOx{97,6};
PairwiseGrowth{42,9}=GrowthRates.HighFiberNoOx{102,9};
PairwiseGrowth{42,10}=GrowthRates.HighFiberNoOx{103,10};
PairwiseGrowth{42,11}=GrowthRates.HighFiberNoOx{104,11};
PairwiseGrowth{42,12}=GrowthRates.HighFiberNoOx{105,12};
PairwiseGrowth{43,2}=GrowthRates.HighFiberNoOx{72,2};
PairwiseGrowth{43,3}=GrowthRates.HighFiberNoOx{80,3};
PairwiseGrowth{43,4}=GrowthRates.HighFiberNoOx{87,4};
PairwiseGrowth{43,5}=GrowthRates.HighFiberNoOx{93,5};
PairwiseGrowth{43,6}=GrowthRates.HighFiberNoOx{98,6};
PairwiseGrowth{43,8}=GrowthRates.HighFiberNoOx{102,8};
PairwiseGrowth{43,10}=GrowthRates.HighFiberNoOx{106,10};
PairwiseGrowth{43,11}=GrowthRates.HighFiberNoOx{107,11};
PairwiseGrowth{43,12}=GrowthRates.HighFiberNoOx{108,12};
PairwiseGrowth{44,2}=GrowthRates.HighFiberNoOx{73,2};
PairwiseGrowth{44,3}=GrowthRates.HighFiberNoOx{81,3};
PairwiseGrowth{44,4}=GrowthRates.HighFiberNoOx{88,4};
PairwiseGrowth{44,5}=GrowthRates.HighFiberNoOx{94,5};
PairwiseGrowth{44,6}=GrowthRates.HighFiberNoOx{99,6};
PairwiseGrowth{44,8}=GrowthRates.HighFiberNoOx{103,8};
PairwiseGrowth{44,9}=GrowthRates.HighFiberNoOx{106,9};
PairwiseGrowth{44,11}=GrowthRates.HighFiberNoOx{109,11};
PairwiseGrowth{44,12}=GrowthRates.HighFiberNoOx{110,12};
PairwiseGrowth{45,2}=GrowthRates.HighFiberNoOx{74,2};
PairwiseGrowth{45,3}=GrowthRates.HighFiberNoOx{82,3};
PairwiseGrowth{45,4}=GrowthRates.HighFiberNoOx{89,4};
PairwiseGrowth{45,5}=GrowthRates.HighFiberNoOx{95,5};
PairwiseGrowth{45,6}=GrowthRates.HighFiberNoOx{100,6};
PairwiseGrowth{45,8}=GrowthRates.HighFiberNoOx{104,8};
PairwiseGrowth{45,9}=GrowthRates.HighFiberNoOx{107,9};
PairwiseGrowth{45,10}=GrowthRates.HighFiberNoOx{109,10};
PairwiseGrowth{45,12}=GrowthRates.HighFiberNoOx{111,12};
PairwiseGrowth{46,2}=GrowthRates.HighFiberNoOx{75,2};
PairwiseGrowth{46,3}=GrowthRates.HighFiberNoOx{83,3};
PairwiseGrowth{46,4}=GrowthRates.HighFiberNoOx{90,4};
PairwiseGrowth{46,5}=GrowthRates.HighFiberNoOx{96,5};
PairwiseGrowth{46,6}=GrowthRates.HighFiberNoOx{101,6};
PairwiseGrowth{46,8}=GrowthRates.HighFiberNoOx{105,8};
PairwiseGrowth{46,9}=GrowthRates.HighFiberNoOx{108,9};
PairwiseGrowth{46,10}=GrowthRates.HighFiberNoOx{110,10};
PairwiseGrowth{46,11}=GrowthRates.HighFiberNoOx{111,11};

PairwiseGrowth{48,2}=GrowthRates.ProteinNoOx{2,2};
PairwiseGrowth{48,3}=GrowthRates.ProteinNoOx{3,3};
PairwiseGrowth{48,4}=GrowthRates.ProteinNoOx{4,4};
PairwiseGrowth{48,5}=GrowthRates.ProteinNoOx{5,5};
PairwiseGrowth{48,6}=GrowthRates.ProteinNoOx{6,6};
PairwiseGrowth{48,8}=GrowthRates.ProteinNoOx{7,8};
PairwiseGrowth{48,9}=GrowthRates.ProteinNoOx{8,9};
PairwiseGrowth{48,10}=GrowthRates.ProteinNoOx{9,10};
PairwiseGrowth{48,11}=GrowthRates.ProteinNoOx{10,11};
PairwiseGrowth{48,12}=GrowthRates.ProteinNoOx{11,12};
PairwiseGrowth{49,2}=GrowthRates.ProteinNoOx{57,2};
PairwiseGrowth{49,3}=GrowthRates.ProteinNoOx{58,3};
PairwiseGrowth{49,4}=GrowthRates.ProteinNoOx{59,4};
PairwiseGrowth{49,5}=GrowthRates.ProteinNoOx{60,5};
PairwiseGrowth{49,6}=GrowthRates.ProteinNoOx{61,6};
PairwiseGrowth{49,8}=GrowthRates.ProteinNoOx{62,8};
PairwiseGrowth{49,9}=GrowthRates.ProteinNoOx{63,9};
PairwiseGrowth{49,10}=GrowthRates.ProteinNoOx{64,10};
PairwiseGrowth{49,11}=GrowthRates.ProteinNoOx{65,11};
PairwiseGrowth{49,12}=GrowthRates.ProteinNoOx{66,12};
PairwiseGrowth{50,3}=GrowthRates.ProteinNoOx{12,3};
PairwiseGrowth{50,4}=GrowthRates.ProteinNoOx{13,4};
PairwiseGrowth{50,5}=GrowthRates.ProteinNoOx{14,5};
PairwiseGrowth{50,6}=GrowthRates.ProteinNoOx{15,6};
PairwiseGrowth{50,8}=GrowthRates.ProteinNoOx{16,8};
PairwiseGrowth{50,9}=GrowthRates.ProteinNoOx{17,9};
PairwiseGrowth{50,10}=GrowthRates.ProteinNoOx{18,10};
PairwiseGrowth{50,11}=GrowthRates.ProteinNoOx{19,11};
PairwiseGrowth{50,12}=GrowthRates.ProteinNoOx{20,12};
PairwiseGrowth{51,2}=GrowthRates.ProteinNoOx{12,2};
PairwiseGrowth{51,4}=GrowthRates.ProteinNoOx{21,4};
PairwiseGrowth{51,5}=GrowthRates.ProteinNoOx{22,5};
PairwiseGrowth{51,6}=GrowthRates.ProteinNoOx{23,6};
PairwiseGrowth{51,8}=GrowthRates.ProteinNoOx{24,8};
PairwiseGrowth{51,9}=GrowthRates.ProteinNoOx{25,9};
PairwiseGrowth{51,10}=GrowthRates.ProteinNoOx{26,10};
PairwiseGrowth{51,11}=GrowthRates.ProteinNoOx{27,11};
PairwiseGrowth{51,12}=GrowthRates.ProteinNoOx{28,12};
PairwiseGrowth{52,2}=GrowthRates.ProteinNoOx{13,2};
PairwiseGrowth{52,3}=GrowthRates.ProteinNoOx{21,3};
PairwiseGrowth{52,5}=GrowthRates.ProteinNoOx{29,5};
PairwiseGrowth{52,6}=GrowthRates.ProteinNoOx{30,6};
PairwiseGrowth{52,8}=GrowthRates.ProteinNoOx{31,8};
PairwiseGrowth{52,9}=GrowthRates.ProteinNoOx{32,9};
PairwiseGrowth{52,10}=GrowthRates.ProteinNoOx{33,10};
PairwiseGrowth{52,11}=GrowthRates.ProteinNoOx{34,11};
PairwiseGrowth{52,12}=GrowthRates.ProteinNoOx{35,12};
PairwiseGrowth{53,2}=GrowthRates.ProteinNoOx{14,2};
PairwiseGrowth{53,3}=GrowthRates.ProteinNoOx{22,3};
PairwiseGrowth{53,4}=GrowthRates.ProteinNoOx{29,4};
PairwiseGrowth{53,6}=GrowthRates.ProteinNoOx{36,6};
PairwiseGrowth{53,8}=GrowthRates.ProteinNoOx{37,8};
PairwiseGrowth{53,9}=GrowthRates.ProteinNoOx{38,9};
PairwiseGrowth{53,10}=GrowthRates.ProteinNoOx{39,10};
PairwiseGrowth{53,11}=GrowthRates.ProteinNoOx{40,11};
PairwiseGrowth{53,12}=GrowthRates.ProteinNoOx{41,12};
PairwiseGrowth{54,2}=GrowthRates.ProteinNoOx{15,2};
PairwiseGrowth{54,3}=GrowthRates.ProteinNoOx{23,3};
PairwiseGrowth{54,4}=GrowthRates.ProteinNoOx{30,4};
PairwiseGrowth{54,5}=GrowthRates.ProteinNoOx{36,5};
PairwiseGrowth{54,8}=GrowthRates.ProteinNoOx{42,8};
PairwiseGrowth{54,9}=GrowthRates.ProteinNoOx{43,9};
PairwiseGrowth{54,10}=GrowthRates.ProteinNoOx{44,10};
PairwiseGrowth{54,11}=GrowthRates.ProteinNoOx{45,11};
PairwiseGrowth{54,12}=GrowthRates.ProteinNoOx{46,12};
PairwiseGrowth{55,2}=GrowthRates.ProteinNoOx{16,2};
PairwiseGrowth{55,3}=GrowthRates.ProteinNoOx{24,3};
PairwiseGrowth{55,4}=GrowthRates.ProteinNoOx{31,4};
PairwiseGrowth{55,5}=GrowthRates.ProteinNoOx{37,5};
PairwiseGrowth{55,6}=GrowthRates.ProteinNoOx{42,6};
PairwiseGrowth{55,9}=GrowthRates.ProteinNoOx{47,9};
PairwiseGrowth{55,10}=GrowthRates.ProteinNoOx{48,10};
PairwiseGrowth{55,11}=GrowthRates.ProteinNoOx{49,11};
PairwiseGrowth{55,12}=GrowthRates.ProteinNoOx{50,12};
PairwiseGrowth{56,2}=GrowthRates.ProteinNoOx{17,2};
PairwiseGrowth{56,3}=GrowthRates.ProteinNoOx{25,3};
PairwiseGrowth{56,4}=GrowthRates.ProteinNoOx{32,4};
PairwiseGrowth{56,5}=GrowthRates.ProteinNoOx{38,5};
PairwiseGrowth{56,6}=GrowthRates.ProteinNoOx{43,6};
PairwiseGrowth{56,8}=GrowthRates.ProteinNoOx{47,8};
PairwiseGrowth{56,10}=GrowthRates.ProteinNoOx{51,10};
PairwiseGrowth{56,11}=GrowthRates.ProteinNoOx{52,11};
PairwiseGrowth{56,12}=GrowthRates.ProteinNoOx{53,12};
PairwiseGrowth{57,2}=GrowthRates.ProteinNoOx{18,2};
PairwiseGrowth{57,3}=GrowthRates.ProteinNoOx{26,3};
PairwiseGrowth{57,4}=GrowthRates.ProteinNoOx{33,4};
PairwiseGrowth{57,5}=GrowthRates.ProteinNoOx{39,5};
PairwiseGrowth{57,6}=GrowthRates.ProteinNoOx{44,6};
PairwiseGrowth{57,8}=GrowthRates.ProteinNoOx{48,8};
PairwiseGrowth{57,9}=GrowthRates.ProteinNoOx{51,9};
PairwiseGrowth{57,11}=GrowthRates.ProteinNoOx{54,11};
PairwiseGrowth{57,12}=GrowthRates.ProteinNoOx{55,12};
PairwiseGrowth{58,2}=GrowthRates.ProteinNoOx{19,2};
PairwiseGrowth{58,3}=GrowthRates.ProteinNoOx{27,3};
PairwiseGrowth{58,4}=GrowthRates.ProteinNoOx{34,4};
PairwiseGrowth{58,5}=GrowthRates.ProteinNoOx{40,5};
PairwiseGrowth{58,6}=GrowthRates.ProteinNoOx{45,6};
PairwiseGrowth{58,8}=GrowthRates.ProteinNoOx{49,8};
PairwiseGrowth{58,9}=GrowthRates.ProteinNoOx{52,9};
PairwiseGrowth{58,10}=GrowthRates.ProteinNoOx{54,10};
PairwiseGrowth{58,12}=GrowthRates.ProteinNoOx{56,12};
PairwiseGrowth{59,2}=GrowthRates.ProteinNoOx{20,2};
PairwiseGrowth{59,3}=GrowthRates.ProteinNoOx{28,3};
PairwiseGrowth{59,4}=GrowthRates.ProteinNoOx{35,4};
PairwiseGrowth{59,5}=GrowthRates.ProteinNoOx{41,5};
PairwiseGrowth{59,6}=GrowthRates.ProteinNoOx{46,6};
PairwiseGrowth{59,8}=GrowthRates.ProteinNoOx{50,8};
PairwiseGrowth{59,9}=GrowthRates.ProteinNoOx{53,9};
PairwiseGrowth{59,10}=GrowthRates.ProteinNoOx{55,10};
PairwiseGrowth{59,11}=GrowthRates.ProteinNoOx{56,11};

PairwiseGrowth{60,3}=GrowthRates.ProteinNoOx{67,3};
PairwiseGrowth{60,4}=GrowthRates.ProteinNoOx{68,4};
PairwiseGrowth{60,5}=GrowthRates.ProteinNoOx{69,5};
PairwiseGrowth{60,6}=GrowthRates.ProteinNoOx{70,6};
PairwiseGrowth{60,8}=GrowthRates.ProteinNoOx{71,8};
PairwiseGrowth{60,9}=GrowthRates.ProteinNoOx{72,9};
PairwiseGrowth{60,10}=GrowthRates.ProteinNoOx{73,10};
PairwiseGrowth{60,11}=GrowthRates.ProteinNoOx{74,11};
PairwiseGrowth{60,12}=GrowthRates.ProteinNoOx{75,12};
PairwiseGrowth{61,2}=GrowthRates.ProteinNoOx{67,2};
PairwiseGrowth{61,4}=GrowthRates.ProteinNoOx{76,4};
PairwiseGrowth{61,5}=GrowthRates.ProteinNoOx{77,5};
PairwiseGrowth{61,6}=GrowthRates.ProteinNoOx{78,6};
PairwiseGrowth{61,8}=GrowthRates.ProteinNoOx{79,8};
PairwiseGrowth{61,9}=GrowthRates.ProteinNoOx{80,9};
PairwiseGrowth{61,10}=GrowthRates.ProteinNoOx{81,10};
PairwiseGrowth{61,11}=GrowthRates.ProteinNoOx{82,11};
PairwiseGrowth{61,12}=GrowthRates.ProteinNoOx{83,12};
PairwiseGrowth{62,2}=GrowthRates.ProteinNoOx{68,2};
PairwiseGrowth{62,3}=GrowthRates.ProteinNoOx{76,3};
PairwiseGrowth{62,5}=GrowthRates.ProteinNoOx{84,5};
PairwiseGrowth{62,6}=GrowthRates.ProteinNoOx{85,6};
PairwiseGrowth{62,8}=GrowthRates.ProteinNoOx{86,8};
PairwiseGrowth{62,9}=GrowthRates.ProteinNoOx{87,9};
PairwiseGrowth{62,10}=GrowthRates.ProteinNoOx{88,10};
PairwiseGrowth{62,11}=GrowthRates.ProteinNoOx{89,11};
PairwiseGrowth{62,12}=GrowthRates.ProteinNoOx{90,12};
PairwiseGrowth{63,2}=GrowthRates.ProteinNoOx{69,2};
PairwiseGrowth{63,3}=GrowthRates.ProteinNoOx{77,3};
PairwiseGrowth{63,4}=GrowthRates.ProteinNoOx{84,4};
PairwiseGrowth{63,6}=GrowthRates.ProteinNoOx{91,6};
PairwiseGrowth{63,8}=GrowthRates.ProteinNoOx{92,8};
PairwiseGrowth{63,9}=GrowthRates.ProteinNoOx{93,9};
PairwiseGrowth{63,10}=GrowthRates.ProteinNoOx{94,10};
PairwiseGrowth{63,11}=GrowthRates.ProteinNoOx{95,11};
PairwiseGrowth{63,12}=GrowthRates.ProteinNoOx{96,12};
PairwiseGrowth{64,2}=GrowthRates.ProteinNoOx{70,2};
PairwiseGrowth{64,3}=GrowthRates.ProteinNoOx{78,3};
PairwiseGrowth{64,4}=GrowthRates.ProteinNoOx{85,4};
PairwiseGrowth{64,5}=GrowthRates.ProteinNoOx{91,5};
PairwiseGrowth{64,8}=GrowthRates.ProteinNoOx{97,8};
PairwiseGrowth{64,9}=GrowthRates.ProteinNoOx{98,9};
PairwiseGrowth{64,10}=GrowthRates.ProteinNoOx{99,10};
PairwiseGrowth{64,11}=GrowthRates.ProteinNoOx{100,11};
PairwiseGrowth{64,12}=GrowthRates.ProteinNoOx{101,12};
PairwiseGrowth{65,2}=GrowthRates.ProteinNoOx{71,2};
PairwiseGrowth{65,3}=GrowthRates.ProteinNoOx{79,3};
PairwiseGrowth{65,4}=GrowthRates.ProteinNoOx{31,4};
PairwiseGrowth{65,5}=GrowthRates.ProteinNoOx{92,5};
PairwiseGrowth{65,6}=GrowthRates.ProteinNoOx{97,6};
PairwiseGrowth{65,9}=GrowthRates.ProteinNoOx{102,9};
PairwiseGrowth{65,10}=GrowthRates.ProteinNoOx{103,10};
PairwiseGrowth{65,11}=GrowthRates.ProteinNoOx{104,11};
PairwiseGrowth{65,12}=GrowthRates.ProteinNoOx{105,12};
PairwiseGrowth{66,2}=GrowthRates.ProteinNoOx{72,2};
PairwiseGrowth{66,3}=GrowthRates.ProteinNoOx{80,3};
PairwiseGrowth{66,4}=GrowthRates.ProteinNoOx{87,4};
PairwiseGrowth{66,5}=GrowthRates.ProteinNoOx{93,5};
PairwiseGrowth{66,6}=GrowthRates.ProteinNoOx{98,6};
PairwiseGrowth{66,8}=GrowthRates.ProteinNoOx{102,8};
PairwiseGrowth{66,10}=GrowthRates.ProteinNoOx{106,10};
PairwiseGrowth{66,11}=GrowthRates.ProteinNoOx{107,11};
PairwiseGrowth{66,12}=GrowthRates.ProteinNoOx{108,12};
PairwiseGrowth{67,2}=GrowthRates.ProteinNoOx{73,2};
PairwiseGrowth{67,3}=GrowthRates.ProteinNoOx{81,3};
PairwiseGrowth{67,4}=GrowthRates.ProteinNoOx{88,4};
PairwiseGrowth{67,5}=GrowthRates.ProteinNoOx{94,5};
PairwiseGrowth{67,6}=GrowthRates.ProteinNoOx{99,6};
PairwiseGrowth{67,8}=GrowthRates.ProteinNoOx{103,8};
PairwiseGrowth{67,9}=GrowthRates.ProteinNoOx{106,9};
PairwiseGrowth{67,11}=GrowthRates.ProteinNoOx{109,11};
PairwiseGrowth{67,12}=GrowthRates.ProteinNoOx{110,12};
PairwiseGrowth{68,2}=GrowthRates.ProteinNoOx{74,2};
PairwiseGrowth{68,3}=GrowthRates.ProteinNoOx{82,3};
PairwiseGrowth{68,4}=GrowthRates.ProteinNoOx{89,4};
PairwiseGrowth{68,5}=GrowthRates.ProteinNoOx{95,5};
PairwiseGrowth{68,6}=GrowthRates.ProteinNoOx{100,6};
PairwiseGrowth{68,8}=GrowthRates.ProteinNoOx{104,8};
PairwiseGrowth{68,9}=GrowthRates.ProteinNoOx{107,9};
PairwiseGrowth{68,10}=GrowthRates.ProteinNoOx{109,10};
PairwiseGrowth{68,12}=GrowthRates.ProteinNoOx{111,12};
PairwiseGrowth{69,2}=GrowthRates.ProteinNoOx{75,2};
PairwiseGrowth{69,3}=GrowthRates.ProteinNoOx{83,3};
PairwiseGrowth{69,4}=GrowthRates.ProteinNoOx{90,4};
PairwiseGrowth{69,5}=GrowthRates.ProteinNoOx{96,5};
PairwiseGrowth{69,6}=GrowthRates.ProteinNoOx{101,6};
PairwiseGrowth{69,8}=GrowthRates.ProteinNoOx{105,8};
PairwiseGrowth{69,9}=GrowthRates.ProteinNoOx{108,9};
PairwiseGrowth{69,10}=GrowthRates.ProteinNoOx{110,10};
PairwiseGrowth{69,11}=GrowthRates.ProteinNoOx{111,11};

PairwiseGrowth{71,2}=GrowthRates.Western{2,2};
PairwiseGrowth{71,3}=GrowthRates.Western{3,3};
PairwiseGrowth{71,4}=GrowthRates.Western{4,4};
PairwiseGrowth{71,5}=GrowthRates.Western{5,5};
PairwiseGrowth{71,6}=GrowthRates.Western{6,6};
PairwiseGrowth{71,7}=GrowthRates.Western{7,7};
PairwiseGrowth{71,8}=GrowthRates.Western{8,8};
PairwiseGrowth{71,9}=GrowthRates.Western{9,9};
PairwiseGrowth{71,10}=GrowthRates.Western{10,10};
PairwiseGrowth{71,11}=GrowthRates.Western{11,11};
PairwiseGrowth{71,12}=GrowthRates.Western{12,12};
PairwiseGrowth{72,2}=GrowthRates.Western{68,2};
PairwiseGrowth{72,3}=GrowthRates.Western{69,3};
PairwiseGrowth{72,4}=GrowthRates.Western{70,4};
PairwiseGrowth{72,5}=GrowthRates.Western{71,5};
PairwiseGrowth{72,6}=GrowthRates.Western{72,6};
PairwiseGrowth{72,7}=GrowthRates.Western{73,7};
PairwiseGrowth{72,8}=GrowthRates.Western{74,8};
PairwiseGrowth{72,9}=GrowthRates.Western{75,9};
PairwiseGrowth{72,10}=GrowthRates.Western{76,10};
PairwiseGrowth{72,11}=GrowthRates.Western{77,11};
PairwiseGrowth{72,12}=GrowthRates.Western{78,12};
PairwiseGrowth{73,3}=GrowthRates.Western{13,3};
PairwiseGrowth{73,4}=GrowthRates.Western{14,4};
PairwiseGrowth{73,5}=GrowthRates.Western{15,5};
PairwiseGrowth{73,6}=GrowthRates.Western{16,6};
PairwiseGrowth{73,7}=GrowthRates.Western{17,7};
PairwiseGrowth{73,8}=GrowthRates.Western{18,8};
PairwiseGrowth{73,9}=GrowthRates.Western{19,9};
PairwiseGrowth{73,10}=GrowthRates.Western{20,10};
PairwiseGrowth{73,11}=GrowthRates.Western{21,11};
PairwiseGrowth{73,12}=GrowthRates.Western{22,12};
PairwiseGrowth{74,2}=GrowthRates.Western{13,2};
PairwiseGrowth{74,4}=GrowthRates.Western{23,4};
PairwiseGrowth{74,5}=GrowthRates.Western{24,5};
PairwiseGrowth{74,6}=GrowthRates.Western{25,6};
PairwiseGrowth{74,7}=GrowthRates.Western{26,7};
PairwiseGrowth{74,8}=GrowthRates.Western{27,8};
PairwiseGrowth{74,9}=GrowthRates.Western{28,9};
PairwiseGrowth{74,10}=GrowthRates.Western{29,10};
PairwiseGrowth{74,11}=GrowthRates.Western{30,11};
PairwiseGrowth{74,12}=GrowthRates.Western{31,12};
PairwiseGrowth{75,2}=GrowthRates.Western{14,2};
PairwiseGrowth{75,3}=GrowthRates.Western{23,3};
PairwiseGrowth{75,5}=GrowthRates.Western{32,5};
PairwiseGrowth{75,6}=GrowthRates.Western{33,6};
PairwiseGrowth{75,7}=GrowthRates.Western{34,7};
PairwiseGrowth{75,8}=GrowthRates.Western{35,8};
PairwiseGrowth{75,9}=GrowthRates.Western{36,9};
PairwiseGrowth{75,10}=GrowthRates.Western{37,10};
PairwiseGrowth{75,11}=GrowthRates.Western{38,11};
PairwiseGrowth{75,12}=GrowthRates.Western{39,12};
PairwiseGrowth{76,2}=GrowthRates.Western{15,2};
PairwiseGrowth{76,3}=GrowthRates.Western{24,3};
PairwiseGrowth{76,4}=GrowthRates.Western{32,4};
PairwiseGrowth{76,6}=GrowthRates.Western{40,6};
PairwiseGrowth{76,7}=GrowthRates.Western{41,7};
PairwiseGrowth{76,8}=GrowthRates.Western{42,8};
PairwiseGrowth{76,9}=GrowthRates.Western{43,9};
PairwiseGrowth{76,10}=GrowthRates.Western{44,10};
PairwiseGrowth{76,11}=GrowthRates.Western{45,11};
PairwiseGrowth{76,12}=GrowthRates.Western{46,12};
PairwiseGrowth{77,2}=GrowthRates.Western{16,2};
PairwiseGrowth{77,3}=GrowthRates.Western{25,3};
PairwiseGrowth{77,4}=GrowthRates.Western{33,4};
PairwiseGrowth{77,5}=GrowthRates.Western{40,5};
PairwiseGrowth{77,7}=GrowthRates.Western{47,7};
PairwiseGrowth{77,8}=GrowthRates.Western{48,8};
PairwiseGrowth{77,9}=GrowthRates.Western{49,9};
PairwiseGrowth{77,10}=GrowthRates.Western{50,10};
PairwiseGrowth{77,11}=GrowthRates.Western{51,11};
PairwiseGrowth{77,12}=GrowthRates.Western{52,12};
PairwiseGrowth{78,2}=GrowthRates.Western{17,2};
PairwiseGrowth{78,3}=GrowthRates.Western{26,3};
PairwiseGrowth{78,4}=GrowthRates.Western{34,4};
PairwiseGrowth{78,5}=GrowthRates.Western{41,5};
PairwiseGrowth{78,6}=GrowthRates.Western{47,6};
PairwiseGrowth{78,8}=GrowthRates.Western{53,8};
PairwiseGrowth{78,9}=GrowthRates.Western{54,9};
PairwiseGrowth{78,10}=GrowthRates.Western{55,10};
PairwiseGrowth{78,11}=GrowthRates.Western{56,11};
PairwiseGrowth{78,12}=GrowthRates.Western{57,12};
PairwiseGrowth{79,2}=GrowthRates.Western{18,2};
PairwiseGrowth{79,3}=GrowthRates.Western{27,3};
PairwiseGrowth{79,4}=GrowthRates.Western{35,4};
PairwiseGrowth{79,5}=GrowthRates.Western{42,5};
PairwiseGrowth{79,6}=GrowthRates.Western{48,6};
PairwiseGrowth{79,7}=GrowthRates.Western{53,7};
PairwiseGrowth{79,9}=GrowthRates.Western{58,9};
PairwiseGrowth{79,10}=GrowthRates.Western{59,10};
PairwiseGrowth{79,11}=GrowthRates.Western{60,11};
PairwiseGrowth{79,12}=GrowthRates.Western{61,12};
PairwiseGrowth{80,2}=GrowthRates.Western{19,2};
PairwiseGrowth{80,3}=GrowthRates.Western{28,3};
PairwiseGrowth{80,4}=GrowthRates.Western{36,4};
PairwiseGrowth{80,5}=GrowthRates.Western{43,5};
PairwiseGrowth{80,6}=GrowthRates.Western{49,6};
PairwiseGrowth{80,7}=GrowthRates.Western{54,7};
PairwiseGrowth{80,8}=GrowthRates.Western{58,8};
PairwiseGrowth{80,10}=GrowthRates.Western{62,10};
PairwiseGrowth{80,11}=GrowthRates.Western{63,11};
PairwiseGrowth{80,12}=GrowthRates.Western{64,12};
PairwiseGrowth{81,2}=GrowthRates.Western{20,2};
PairwiseGrowth{81,3}=GrowthRates.Western{29,3};
PairwiseGrowth{81,4}=GrowthRates.Western{37,4};
PairwiseGrowth{81,5}=GrowthRates.Western{44,5};
PairwiseGrowth{81,6}=GrowthRates.Western{50,6};
PairwiseGrowth{81,7}=GrowthRates.Western{55,7};
PairwiseGrowth{81,8}=GrowthRates.Western{59,8};
PairwiseGrowth{81,9}=GrowthRates.Western{62,9};
PairwiseGrowth{81,11}=GrowthRates.Western{65,11};
PairwiseGrowth{81,12}=GrowthRates.Western{66,12};
PairwiseGrowth{82,2}=GrowthRates.Western{21,2};
PairwiseGrowth{82,3}=GrowthRates.Western{30,3};
PairwiseGrowth{82,4}=GrowthRates.Western{38,4};
PairwiseGrowth{82,5}=GrowthRates.Western{45,5};
PairwiseGrowth{82,6}=GrowthRates.Western{51,6};
PairwiseGrowth{82,7}=GrowthRates.Western{56,7};
PairwiseGrowth{82,8}=GrowthRates.Western{60,8};
PairwiseGrowth{82,9}=GrowthRates.Western{63,9};
PairwiseGrowth{82,10}=GrowthRates.Western{65,10};
PairwiseGrowth{82,12}=GrowthRates.Western{67,12};
PairwiseGrowth{83,2}=GrowthRates.Western{22,2};
PairwiseGrowth{83,3}=GrowthRates.Western{31,3};
PairwiseGrowth{83,4}=GrowthRates.Western{39,4};
PairwiseGrowth{83,5}=GrowthRates.Western{46,5};
PairwiseGrowth{83,6}=GrowthRates.Western{52,6};
PairwiseGrowth{83,7}=GrowthRates.Western{57,7};
PairwiseGrowth{83,8}=GrowthRates.Western{61,8};
PairwiseGrowth{83,9}=GrowthRates.Western{64,9};
PairwiseGrowth{83,10}=GrowthRates.Western{66,10};
PairwiseGrowth{83,11}=GrowthRates.Western{67,11};
PairwiseGrowth{84,3}=GrowthRates.Western{79,3};
PairwiseGrowth{84,4}=GrowthRates.Western{80,4};
PairwiseGrowth{84,5}=GrowthRates.Western{81,5};
PairwiseGrowth{84,6}=GrowthRates.Western{82,6};
PairwiseGrowth{84,7}=GrowthRates.Western{83,7};
PairwiseGrowth{84,8}=GrowthRates.Western{84,8};
PairwiseGrowth{84,9}=GrowthRates.Western{85,9};
PairwiseGrowth{84,10}=GrowthRates.Western{86,10};
PairwiseGrowth{84,11}=GrowthRates.Western{87,11};
PairwiseGrowth{84,12}=GrowthRates.Western{88,12};
PairwiseGrowth{85,2}=GrowthRates.Western{79,2};
PairwiseGrowth{85,4}=GrowthRates.Western{89,4};
PairwiseGrowth{85,5}=GrowthRates.Western{90,5};
PairwiseGrowth{85,6}=GrowthRates.Western{91,6};
PairwiseGrowth{85,7}=GrowthRates.Western{92,7};
PairwiseGrowth{85,8}=GrowthRates.Western{93,8};
PairwiseGrowth{85,9}=GrowthRates.Western{94,9};
PairwiseGrowth{85,10}=GrowthRates.Western{95,10};
PairwiseGrowth{85,11}=GrowthRates.Western{96,11};
PairwiseGrowth{85,12}=GrowthRates.Western{97,12};
PairwiseGrowth{86,2}=GrowthRates.Western{80,2};
PairwiseGrowth{86,3}=GrowthRates.Western{89,3};
PairwiseGrowth{86,5}=GrowthRates.Western{98,5};
PairwiseGrowth{86,6}=GrowthRates.Western{99,6};
PairwiseGrowth{86,7}=GrowthRates.Western{100,7};
PairwiseGrowth{86,8}=GrowthRates.Western{101,8};
PairwiseGrowth{86,9}=GrowthRates.Western{102,9};
PairwiseGrowth{86,10}=GrowthRates.Western{103,10};
PairwiseGrowth{86,11}=GrowthRates.Western{104,11};
PairwiseGrowth{86,12}=GrowthRates.Western{105,12};
PairwiseGrowth{87,2}=GrowthRates.Western{81,2};
PairwiseGrowth{87,3}=GrowthRates.Western{90,3};
PairwiseGrowth{87,4}=GrowthRates.Western{98,4};
PairwiseGrowth{87,6}=GrowthRates.Western{106,6};
PairwiseGrowth{87,7}=GrowthRates.Western{107,7};
PairwiseGrowth{87,8}=GrowthRates.Western{108,8};
PairwiseGrowth{87,9}=GrowthRates.Western{109,9};
PairwiseGrowth{87,10}=GrowthRates.Western{110,10};
PairwiseGrowth{87,11}=GrowthRates.Western{111,11};
PairwiseGrowth{87,12}=GrowthRates.Western{112,12};
PairwiseGrowth{88,2}=GrowthRates.Western{82,2};
PairwiseGrowth{88,3}=GrowthRates.Western{91,3};
PairwiseGrowth{88,4}=GrowthRates.Western{99,4};
PairwiseGrowth{88,5}=GrowthRates.Western{106,5};
PairwiseGrowth{88,7}=GrowthRates.Western{113,7};
PairwiseGrowth{88,8}=GrowthRates.Western{114,8};
PairwiseGrowth{88,9}=GrowthRates.Western{115,9};
PairwiseGrowth{88,10}=GrowthRates.Western{116,10};
PairwiseGrowth{88,11}=GrowthRates.Western{117,11};
PairwiseGrowth{88,12}=GrowthRates.Western{118,12};
PairwiseGrowth{89,2}=GrowthRates.Western{83,2};
PairwiseGrowth{89,3}=GrowthRates.Western{92,3};
PairwiseGrowth{89,4}=GrowthRates.Western{100,4};
PairwiseGrowth{89,5}=GrowthRates.Western{107,5};
PairwiseGrowth{89,6}=GrowthRates.Western{113,6};
PairwiseGrowth{89,8}=GrowthRates.Western{119,8};
PairwiseGrowth{89,9}=GrowthRates.Western{120,9};
PairwiseGrowth{89,10}=GrowthRates.Western{121,10};
PairwiseGrowth{89,11}=GrowthRates.Western{122,11};
PairwiseGrowth{89,12}=GrowthRates.Western{123,12};
PairwiseGrowth{90,2}=GrowthRates.Western{84,2};
PairwiseGrowth{90,3}=GrowthRates.Western{93,3};
PairwiseGrowth{90,4}=GrowthRates.Western{101,4};
PairwiseGrowth{90,5}=GrowthRates.Western{108,5};
PairwiseGrowth{90,6}=GrowthRates.Western{114,6};
PairwiseGrowth{90,7}=GrowthRates.Western{119,7};
PairwiseGrowth{90,9}=GrowthRates.Western{124,9};
PairwiseGrowth{90,10}=GrowthRates.Western{125,10};
PairwiseGrowth{90,11}=GrowthRates.Western{126,11};
PairwiseGrowth{90,12}=GrowthRates.Western{127,12};
PairwiseGrowth{91,2}=GrowthRates.Western{85,2};
PairwiseGrowth{91,3}=GrowthRates.Western{94,3};
PairwiseGrowth{91,4}=GrowthRates.Western{102,4};
PairwiseGrowth{91,5}=GrowthRates.Western{109,5};
PairwiseGrowth{91,6}=GrowthRates.Western{115,6};
PairwiseGrowth{91,7}=GrowthRates.Western{120,7};
PairwiseGrowth{91,8}=GrowthRates.Western{124,8};
PairwiseGrowth{91,10}=GrowthRates.Western{128,10};
PairwiseGrowth{91,11}=GrowthRates.Western{129,11};
PairwiseGrowth{91,12}=GrowthRates.Western{130,12};
PairwiseGrowth{92,2}=GrowthRates.Western{86,2};
PairwiseGrowth{92,3}=GrowthRates.Western{95,3};
PairwiseGrowth{92,4}=GrowthRates.Western{103,4};
PairwiseGrowth{92,5}=GrowthRates.Western{110,5};
PairwiseGrowth{92,6}=GrowthRates.Western{116,6};
PairwiseGrowth{92,7}=GrowthRates.Western{121,7};
PairwiseGrowth{92,8}=GrowthRates.Western{125,8};
PairwiseGrowth{92,9}=GrowthRates.Western{128,9};
PairwiseGrowth{92,11}=GrowthRates.Western{131,11};
PairwiseGrowth{92,12}=GrowthRates.Western{132,12};
PairwiseGrowth{93,2}=GrowthRates.Western{87,2};
PairwiseGrowth{93,3}=GrowthRates.Western{96,3};
PairwiseGrowth{93,4}=GrowthRates.Western{104,4};
PairwiseGrowth{93,5}=GrowthRates.Western{111,5};
PairwiseGrowth{93,6}=GrowthRates.Western{117,6};
PairwiseGrowth{93,7}=GrowthRates.Western{122,7};
PairwiseGrowth{93,8}=GrowthRates.Western{126,8};
PairwiseGrowth{93,9}=GrowthRates.Western{129,9};
PairwiseGrowth{93,10}=GrowthRates.Western{131,10};
PairwiseGrowth{93,12}=GrowthRates.Western{133,12};
PairwiseGrowth{94,2}=GrowthRates.Western{88,2};
PairwiseGrowth{94,3}=GrowthRates.Western{97,3};
PairwiseGrowth{94,4}=GrowthRates.Western{105,4};
PairwiseGrowth{94,5}=GrowthRates.Western{112,5};
PairwiseGrowth{94,6}=GrowthRates.Western{118,6};
PairwiseGrowth{94,7}=GrowthRates.Western{123,7};
PairwiseGrowth{94,8}=GrowthRates.Western{127,8};
PairwiseGrowth{94,9}=GrowthRates.Western{130,9};
PairwiseGrowth{94,10}=GrowthRates.Western{132,10};
PairwiseGrowth{94,11}=GrowthRates.Western{133,11};

PairwiseGrowth{96,2}=GrowthRates.HighFiber{2,2};
PairwiseGrowth{96,3}=GrowthRates.HighFiber{3,3};
PairwiseGrowth{96,4}=GrowthRates.HighFiber{4,4};
PairwiseGrowth{96,5}=GrowthRates.HighFiber{5,5};
PairwiseGrowth{96,6}=GrowthRates.HighFiber{6,6};
PairwiseGrowth{96,7}=GrowthRates.HighFiber{7,7};
PairwiseGrowth{96,8}=GrowthRates.HighFiber{8,8};
PairwiseGrowth{96,9}=GrowthRates.HighFiber{9,9};
PairwiseGrowth{96,10}=GrowthRates.HighFiber{10,10};
PairwiseGrowth{96,11}=GrowthRates.HighFiber{11,11};
PairwiseGrowth{96,12}=GrowthRates.HighFiber{12,12};
PairwiseGrowth{97,2}=GrowthRates.HighFiber{68,2};
PairwiseGrowth{97,3}=GrowthRates.HighFiber{69,3};
PairwiseGrowth{97,4}=GrowthRates.HighFiber{70,4};
PairwiseGrowth{97,5}=GrowthRates.HighFiber{71,5};
PairwiseGrowth{97,6}=GrowthRates.HighFiber{72,6};
PairwiseGrowth{97,7}=GrowthRates.HighFiber{73,7};
PairwiseGrowth{97,8}=GrowthRates.HighFiber{74,8};
PairwiseGrowth{97,9}=GrowthRates.HighFiber{75,9};
PairwiseGrowth{97,10}=GrowthRates.HighFiber{76,10};
PairwiseGrowth{97,11}=GrowthRates.HighFiber{77,11};
PairwiseGrowth{97,12}=GrowthRates.HighFiber{78,12};
PairwiseGrowth{98,3}=GrowthRates.HighFiber{13,3};
PairwiseGrowth{98,4}=GrowthRates.HighFiber{14,4};
PairwiseGrowth{98,5}=GrowthRates.HighFiber{15,5};
PairwiseGrowth{98,6}=GrowthRates.HighFiber{16,6};
PairwiseGrowth{98,7}=GrowthRates.HighFiber{17,7};
PairwiseGrowth{98,8}=GrowthRates.HighFiber{18,8};
PairwiseGrowth{98,9}=GrowthRates.HighFiber{19,9};
PairwiseGrowth{98,10}=GrowthRates.HighFiber{20,10};
PairwiseGrowth{98,11}=GrowthRates.HighFiber{21,11};
PairwiseGrowth{98,12}=GrowthRates.HighFiber{22,12};
PairwiseGrowth{99,2}=GrowthRates.HighFiber{13,2};
PairwiseGrowth{99,4}=GrowthRates.HighFiber{23,4};
PairwiseGrowth{99,5}=GrowthRates.HighFiber{24,5};
PairwiseGrowth{99,6}=GrowthRates.HighFiber{25,6};
PairwiseGrowth{99,7}=GrowthRates.HighFiber{26,7};
PairwiseGrowth{99,8}=GrowthRates.HighFiber{27,8};
PairwiseGrowth{99,9}=GrowthRates.HighFiber{28,9};
PairwiseGrowth{99,10}=GrowthRates.HighFiber{29,10};
PairwiseGrowth{99,11}=GrowthRates.HighFiber{30,11};
PairwiseGrowth{99,12}=GrowthRates.HighFiber{31,12};
PairwiseGrowth{100,2}=GrowthRates.HighFiber{14,2};
PairwiseGrowth{100,3}=GrowthRates.HighFiber{23,3};
PairwiseGrowth{100,5}=GrowthRates.HighFiber{32,5};
PairwiseGrowth{100,6}=GrowthRates.HighFiber{33,6};
PairwiseGrowth{100,7}=GrowthRates.HighFiber{34,7};
PairwiseGrowth{100,8}=GrowthRates.HighFiber{35,8};
PairwiseGrowth{100,9}=GrowthRates.HighFiber{36,9};
PairwiseGrowth{100,10}=GrowthRates.HighFiber{37,10};
PairwiseGrowth{100,11}=GrowthRates.HighFiber{38,11};
PairwiseGrowth{100,12}=GrowthRates.HighFiber{39,12};
PairwiseGrowth{101,2}=GrowthRates.HighFiber{15,2};
PairwiseGrowth{101,3}=GrowthRates.HighFiber{24,3};
PairwiseGrowth{101,4}=GrowthRates.HighFiber{32,4};
PairwiseGrowth{101,6}=GrowthRates.HighFiber{40,6};
PairwiseGrowth{101,7}=GrowthRates.HighFiber{41,7};
PairwiseGrowth{101,8}=GrowthRates.HighFiber{42,8};
PairwiseGrowth{101,9}=GrowthRates.HighFiber{43,9};
PairwiseGrowth{101,10}=GrowthRates.HighFiber{44,10};
PairwiseGrowth{101,11}=GrowthRates.HighFiber{45,11};
PairwiseGrowth{101,12}=GrowthRates.HighFiber{46,12};
PairwiseGrowth{102,2}=GrowthRates.HighFiber{16,2};
PairwiseGrowth{102,3}=GrowthRates.HighFiber{25,3};
PairwiseGrowth{102,4}=GrowthRates.HighFiber{33,4};
PairwiseGrowth{102,5}=GrowthRates.HighFiber{40,5};
PairwiseGrowth{102,7}=GrowthRates.HighFiber{47,7};
PairwiseGrowth{102,8}=GrowthRates.HighFiber{48,8};
PairwiseGrowth{102,9}=GrowthRates.HighFiber{49,9};
PairwiseGrowth{102,10}=GrowthRates.HighFiber{50,10};
PairwiseGrowth{102,11}=GrowthRates.HighFiber{51,11};
PairwiseGrowth{102,12}=GrowthRates.HighFiber{52,12};
PairwiseGrowth{103,2}=GrowthRates.HighFiber{17,2};
PairwiseGrowth{103,3}=GrowthRates.HighFiber{26,3};
PairwiseGrowth{103,4}=GrowthRates.HighFiber{34,4};
PairwiseGrowth{103,5}=GrowthRates.HighFiber{41,5};
PairwiseGrowth{103,6}=GrowthRates.HighFiber{47,6};
PairwiseGrowth{103,8}=GrowthRates.HighFiber{53,8};
PairwiseGrowth{103,9}=GrowthRates.HighFiber{54,9};
PairwiseGrowth{103,10}=GrowthRates.HighFiber{55,10};
PairwiseGrowth{103,11}=GrowthRates.HighFiber{56,11};
PairwiseGrowth{103,12}=GrowthRates.HighFiber{57,12};
PairwiseGrowth{104,2}=GrowthRates.HighFiber{18,2};
PairwiseGrowth{104,3}=GrowthRates.HighFiber{27,3};
PairwiseGrowth{104,4}=GrowthRates.HighFiber{35,4};
PairwiseGrowth{104,5}=GrowthRates.HighFiber{42,5};
PairwiseGrowth{104,6}=GrowthRates.HighFiber{48,6};
PairwiseGrowth{104,7}=GrowthRates.HighFiber{53,7};
PairwiseGrowth{104,9}=GrowthRates.HighFiber{58,9};
PairwiseGrowth{104,10}=GrowthRates.HighFiber{59,10};
PairwiseGrowth{104,11}=GrowthRates.HighFiber{60,11};
PairwiseGrowth{104,12}=GrowthRates.HighFiber{61,12};
PairwiseGrowth{105,2}=GrowthRates.HighFiber{19,2};
PairwiseGrowth{105,3}=GrowthRates.HighFiber{28,3};
PairwiseGrowth{105,4}=GrowthRates.HighFiber{36,4};
PairwiseGrowth{105,5}=GrowthRates.HighFiber{43,5};
PairwiseGrowth{105,6}=GrowthRates.HighFiber{49,6};
PairwiseGrowth{105,7}=GrowthRates.HighFiber{54,7};
PairwiseGrowth{105,8}=GrowthRates.HighFiber{58,8};
PairwiseGrowth{105,10}=GrowthRates.HighFiber{62,10};
PairwiseGrowth{105,11}=GrowthRates.HighFiber{63,11};
PairwiseGrowth{105,12}=GrowthRates.HighFiber{64,12};
PairwiseGrowth{106,2}=GrowthRates.HighFiber{20,2};
PairwiseGrowth{106,3}=GrowthRates.HighFiber{29,3};
PairwiseGrowth{106,4}=GrowthRates.HighFiber{37,4};
PairwiseGrowth{106,5}=GrowthRates.HighFiber{44,5};
PairwiseGrowth{106,6}=GrowthRates.HighFiber{50,6};
PairwiseGrowth{106,7}=GrowthRates.HighFiber{55,7};
PairwiseGrowth{106,8}=GrowthRates.HighFiber{59,8};
PairwiseGrowth{106,9}=GrowthRates.HighFiber{62,9};
PairwiseGrowth{106,11}=GrowthRates.HighFiber{65,11};
PairwiseGrowth{106,12}=GrowthRates.HighFiber{66,12};
PairwiseGrowth{107,2}=GrowthRates.HighFiber{21,2};
PairwiseGrowth{107,3}=GrowthRates.HighFiber{30,3};
PairwiseGrowth{107,4}=GrowthRates.HighFiber{38,4};
PairwiseGrowth{107,5}=GrowthRates.HighFiber{45,5};
PairwiseGrowth{107,6}=GrowthRates.HighFiber{51,6};
PairwiseGrowth{107,7}=GrowthRates.HighFiber{56,7};
PairwiseGrowth{107,8}=GrowthRates.HighFiber{60,8};
PairwiseGrowth{107,9}=GrowthRates.HighFiber{63,9};
PairwiseGrowth{107,10}=GrowthRates.HighFiber{65,10};
PairwiseGrowth{107,12}=GrowthRates.HighFiber{67,12};
PairwiseGrowth{108,2}=GrowthRates.HighFiber{22,2};
PairwiseGrowth{108,3}=GrowthRates.HighFiber{31,3};
PairwiseGrowth{108,4}=GrowthRates.HighFiber{39,4};
PairwiseGrowth{108,5}=GrowthRates.HighFiber{46,5};
PairwiseGrowth{108,6}=GrowthRates.HighFiber{52,6};
PairwiseGrowth{108,7}=GrowthRates.HighFiber{57,7};
PairwiseGrowth{108,8}=GrowthRates.HighFiber{61,8};
PairwiseGrowth{108,9}=GrowthRates.HighFiber{64,9};
PairwiseGrowth{108,10}=GrowthRates.HighFiber{66,10};
PairwiseGrowth{108,11}=GrowthRates.HighFiber{67,11};
PairwiseGrowth{109,3}=GrowthRates.HighFiber{79,3};
PairwiseGrowth{109,4}=GrowthRates.HighFiber{80,4};
PairwiseGrowth{109,5}=GrowthRates.HighFiber{81,5};
PairwiseGrowth{109,6}=GrowthRates.HighFiber{82,6};
PairwiseGrowth{109,7}=GrowthRates.HighFiber{83,7};
PairwiseGrowth{109,8}=GrowthRates.HighFiber{84,8};
PairwiseGrowth{109,9}=GrowthRates.HighFiber{85,9};
PairwiseGrowth{109,10}=GrowthRates.HighFiber{86,10};
PairwiseGrowth{109,11}=GrowthRates.HighFiber{87,11};
PairwiseGrowth{109,12}=GrowthRates.HighFiber{88,12};
PairwiseGrowth{110,2}=GrowthRates.HighFiber{79,2};
PairwiseGrowth{110,4}=GrowthRates.HighFiber{89,4};
PairwiseGrowth{110,5}=GrowthRates.HighFiber{90,5};
PairwiseGrowth{110,6}=GrowthRates.HighFiber{91,6};
PairwiseGrowth{110,7}=GrowthRates.HighFiber{92,7};
PairwiseGrowth{110,8}=GrowthRates.HighFiber{93,8};
PairwiseGrowth{110,9}=GrowthRates.HighFiber{94,9};
PairwiseGrowth{110,10}=GrowthRates.HighFiber{95,10};
PairwiseGrowth{110,11}=GrowthRates.HighFiber{96,11};
PairwiseGrowth{110,12}=GrowthRates.HighFiber{97,12};
PairwiseGrowth{111,2}=GrowthRates.HighFiber{80,2};
PairwiseGrowth{111,3}=GrowthRates.HighFiber{89,3};
PairwiseGrowth{111,5}=GrowthRates.HighFiber{98,5};
PairwiseGrowth{111,6}=GrowthRates.HighFiber{99,6};
PairwiseGrowth{111,7}=GrowthRates.HighFiber{100,7};
PairwiseGrowth{111,8}=GrowthRates.HighFiber{101,8};
PairwiseGrowth{111,9}=GrowthRates.HighFiber{102,9};
PairwiseGrowth{111,10}=GrowthRates.HighFiber{103,10};
PairwiseGrowth{111,11}=GrowthRates.HighFiber{104,11};
PairwiseGrowth{111,12}=GrowthRates.HighFiber{105,12};
PairwiseGrowth{112,2}=GrowthRates.HighFiber{81,2};
PairwiseGrowth{112,3}=GrowthRates.HighFiber{90,3};
PairwiseGrowth{112,4}=GrowthRates.HighFiber{98,4};
PairwiseGrowth{112,6}=GrowthRates.HighFiber{106,6};
PairwiseGrowth{112,7}=GrowthRates.HighFiber{107,7};
PairwiseGrowth{112,8}=GrowthRates.HighFiber{108,8};
PairwiseGrowth{112,9}=GrowthRates.HighFiber{109,9};
PairwiseGrowth{112,10}=GrowthRates.HighFiber{110,10};
PairwiseGrowth{112,11}=GrowthRates.HighFiber{111,11};
PairwiseGrowth{112,12}=GrowthRates.HighFiber{112,12};
PairwiseGrowth{113,2}=GrowthRates.HighFiber{82,2};
PairwiseGrowth{113,3}=GrowthRates.HighFiber{91,3};
PairwiseGrowth{113,4}=GrowthRates.HighFiber{99,4};
PairwiseGrowth{113,5}=GrowthRates.HighFiber{106,5};
PairwiseGrowth{113,7}=GrowthRates.HighFiber{113,7};
PairwiseGrowth{113,8}=GrowthRates.HighFiber{114,8};
PairwiseGrowth{113,9}=GrowthRates.HighFiber{115,9};
PairwiseGrowth{113,10}=GrowthRates.HighFiber{116,10};
PairwiseGrowth{113,11}=GrowthRates.HighFiber{117,11};
PairwiseGrowth{113,12}=GrowthRates.HighFiber{118,12};
PairwiseGrowth{114,2}=GrowthRates.HighFiber{83,2};
PairwiseGrowth{114,3}=GrowthRates.HighFiber{92,3};
PairwiseGrowth{114,4}=GrowthRates.HighFiber{100,4};
PairwiseGrowth{114,5}=GrowthRates.HighFiber{107,5};
PairwiseGrowth{114,6}=GrowthRates.HighFiber{113,6};
PairwiseGrowth{114,8}=GrowthRates.HighFiber{119,8};
PairwiseGrowth{114,9}=GrowthRates.HighFiber{120,9};
PairwiseGrowth{114,10}=GrowthRates.HighFiber{121,10};
PairwiseGrowth{114,11}=GrowthRates.HighFiber{122,11};
PairwiseGrowth{114,12}=GrowthRates.HighFiber{123,12};
PairwiseGrowth{115,2}=GrowthRates.HighFiber{84,2};
PairwiseGrowth{115,3}=GrowthRates.HighFiber{93,3};
PairwiseGrowth{115,4}=GrowthRates.HighFiber{101,4};
PairwiseGrowth{115,5}=GrowthRates.HighFiber{108,5};
PairwiseGrowth{115,6}=GrowthRates.HighFiber{114,6};
PairwiseGrowth{115,7}=GrowthRates.HighFiber{119,7};
PairwiseGrowth{115,9}=GrowthRates.HighFiber{124,9};
PairwiseGrowth{115,10}=GrowthRates.HighFiber{125,10};
PairwiseGrowth{115,11}=GrowthRates.HighFiber{126,11};
PairwiseGrowth{115,12}=GrowthRates.HighFiber{127,12};
PairwiseGrowth{116,2}=GrowthRates.HighFiber{85,2};
PairwiseGrowth{116,3}=GrowthRates.HighFiber{94,3};
PairwiseGrowth{116,4}=GrowthRates.HighFiber{102,4};
PairwiseGrowth{116,5}=GrowthRates.HighFiber{109,5};
PairwiseGrowth{116,6}=GrowthRates.HighFiber{115,6};
PairwiseGrowth{116,7}=GrowthRates.HighFiber{120,7};
PairwiseGrowth{116,8}=GrowthRates.HighFiber{124,8};
PairwiseGrowth{116,10}=GrowthRates.HighFiber{128,10};
PairwiseGrowth{116,11}=GrowthRates.HighFiber{129,11};
PairwiseGrowth{116,12}=GrowthRates.HighFiber{130,12};
PairwiseGrowth{117,2}=GrowthRates.HighFiber{86,2};
PairwiseGrowth{117,3}=GrowthRates.HighFiber{95,3};
PairwiseGrowth{117,4}=GrowthRates.HighFiber{103,4};
PairwiseGrowth{117,5}=GrowthRates.HighFiber{110,5};
PairwiseGrowth{117,6}=GrowthRates.HighFiber{116,6};
PairwiseGrowth{117,7}=GrowthRates.HighFiber{121,7};
PairwiseGrowth{117,8}=GrowthRates.HighFiber{125,8};
PairwiseGrowth{117,9}=GrowthRates.HighFiber{128,9};
PairwiseGrowth{117,11}=GrowthRates.HighFiber{131,11};
PairwiseGrowth{117,12}=GrowthRates.HighFiber{132,12};
PairwiseGrowth{118,2}=GrowthRates.HighFiber{87,2};
PairwiseGrowth{118,3}=GrowthRates.HighFiber{96,3};
PairwiseGrowth{118,4}=GrowthRates.HighFiber{104,4};
PairwiseGrowth{118,5}=GrowthRates.HighFiber{111,5};
PairwiseGrowth{118,6}=GrowthRates.HighFiber{117,6};
PairwiseGrowth{118,7}=GrowthRates.HighFiber{122,7};
PairwiseGrowth{118,8}=GrowthRates.HighFiber{126,8};
PairwiseGrowth{118,9}=GrowthRates.HighFiber{129,9};
PairwiseGrowth{118,10}=GrowthRates.HighFiber{131,10};
PairwiseGrowth{118,12}=GrowthRates.HighFiber{133,12};
PairwiseGrowth{119,2}=GrowthRates.HighFiber{88,2};
PairwiseGrowth{119,3}=GrowthRates.HighFiber{97,3};
PairwiseGrowth{119,4}=GrowthRates.HighFiber{105,4};
PairwiseGrowth{119,5}=GrowthRates.HighFiber{112,5};
PairwiseGrowth{119,6}=GrowthRates.HighFiber{118,6};
PairwiseGrowth{119,7}=GrowthRates.HighFiber{123,7};
PairwiseGrowth{119,8}=GrowthRates.HighFiber{127,8};
PairwiseGrowth{119,9}=GrowthRates.HighFiber{130,9};
PairwiseGrowth{119,10}=GrowthRates.HighFiber{132,10};
PairwiseGrowth{119,11}=GrowthRates.HighFiber{133,11};

PairwiseGrowth{121,2}=GrowthRates.Protein{2,2};
PairwiseGrowth{121,3}=GrowthRates.Protein{3,3};
PairwiseGrowth{121,4}=GrowthRates.Protein{4,4};
PairwiseGrowth{121,5}=GrowthRates.Protein{5,5};
PairwiseGrowth{121,6}=GrowthRates.Protein{6,6};
PairwiseGrowth{121,7}=GrowthRates.Protein{7,7};
PairwiseGrowth{121,8}=GrowthRates.Protein{8,8};
PairwiseGrowth{121,9}=GrowthRates.Protein{9,9};
PairwiseGrowth{121,10}=GrowthRates.Protein{10,10};
PairwiseGrowth{121,11}=GrowthRates.Protein{11,11};
PairwiseGrowth{121,12}=GrowthRates.Protein{12,12};
PairwiseGrowth{122,2}=GrowthRates.Protein{68,2};
PairwiseGrowth{122,3}=GrowthRates.Protein{69,3};
PairwiseGrowth{122,4}=GrowthRates.Protein{70,4};
PairwiseGrowth{122,5}=GrowthRates.Protein{71,5};
PairwiseGrowth{122,6}=GrowthRates.Protein{72,6};
PairwiseGrowth{122,7}=GrowthRates.Protein{73,7};
PairwiseGrowth{122,8}=GrowthRates.Protein{74,8};
PairwiseGrowth{122,9}=GrowthRates.Protein{75,9};
PairwiseGrowth{122,10}=GrowthRates.Protein{76,10};
PairwiseGrowth{122,11}=GrowthRates.Protein{77,11};
PairwiseGrowth{122,12}=GrowthRates.Protein{78,12};
PairwiseGrowth{123,3}=GrowthRates.Protein{13,3};
PairwiseGrowth{123,4}=GrowthRates.Protein{14,4};
PairwiseGrowth{123,5}=GrowthRates.Protein{15,5};
PairwiseGrowth{123,6}=GrowthRates.Protein{16,6};
PairwiseGrowth{123,7}=GrowthRates.Protein{17,7};
PairwiseGrowth{123,8}=GrowthRates.Protein{18,8};
PairwiseGrowth{123,9}=GrowthRates.Protein{19,9};
PairwiseGrowth{123,10}=GrowthRates.Protein{20,10};
PairwiseGrowth{123,11}=GrowthRates.Protein{21,11};
PairwiseGrowth{123,12}=GrowthRates.Protein{22,12};
PairwiseGrowth{124,2}=GrowthRates.Protein{13,2};
PairwiseGrowth{124,4}=GrowthRates.Protein{23,4};
PairwiseGrowth{124,5}=GrowthRates.Protein{24,5};
PairwiseGrowth{124,6}=GrowthRates.Protein{25,6};
PairwiseGrowth{124,7}=GrowthRates.Protein{26,7};
PairwiseGrowth{124,8}=GrowthRates.Protein{27,8};
PairwiseGrowth{124,9}=GrowthRates.Protein{28,9};
PairwiseGrowth{124,10}=GrowthRates.Protein{29,10};
PairwiseGrowth{124,11}=GrowthRates.Protein{30,11};
PairwiseGrowth{124,12}=GrowthRates.Protein{31,12};
PairwiseGrowth{125,2}=GrowthRates.Protein{14,2};
PairwiseGrowth{125,3}=GrowthRates.Protein{23,3};
PairwiseGrowth{125,5}=GrowthRates.Protein{32,5};
PairwiseGrowth{125,6}=GrowthRates.Protein{33,6};
PairwiseGrowth{125,7}=GrowthRates.Protein{34,7};
PairwiseGrowth{125,8}=GrowthRates.Protein{35,8};
PairwiseGrowth{125,9}=GrowthRates.Protein{36,9};
PairwiseGrowth{125,10}=GrowthRates.Protein{37,10};
PairwiseGrowth{125,11}=GrowthRates.Protein{38,11};
PairwiseGrowth{125,12}=GrowthRates.Protein{39,12};
PairwiseGrowth{126,2}=GrowthRates.Protein{15,2};
PairwiseGrowth{126,3}=GrowthRates.Protein{24,3};
PairwiseGrowth{126,4}=GrowthRates.Protein{32,4};
PairwiseGrowth{126,6}=GrowthRates.Protein{40,6};
PairwiseGrowth{126,7}=GrowthRates.Protein{41,7};
PairwiseGrowth{126,8}=GrowthRates.Protein{42,8};
PairwiseGrowth{126,9}=GrowthRates.Protein{43,9};
PairwiseGrowth{126,10}=GrowthRates.Protein{44,10};
PairwiseGrowth{126,11}=GrowthRates.Protein{45,11};
PairwiseGrowth{126,12}=GrowthRates.Protein{46,12};
PairwiseGrowth{127,2}=GrowthRates.Protein{16,2};
PairwiseGrowth{127,3}=GrowthRates.Protein{25,3};
PairwiseGrowth{127,4}=GrowthRates.Protein{33,4};
PairwiseGrowth{127,5}=GrowthRates.Protein{40,5};
PairwiseGrowth{127,7}=GrowthRates.Protein{47,7};
PairwiseGrowth{127,8}=GrowthRates.Protein{48,8};
PairwiseGrowth{127,9}=GrowthRates.Protein{49,9};
PairwiseGrowth{127,10}=GrowthRates.Protein{50,10};
PairwiseGrowth{127,11}=GrowthRates.Protein{51,11};
PairwiseGrowth{127,12}=GrowthRates.Protein{52,12};
PairwiseGrowth{128,2}=GrowthRates.Protein{17,2};
PairwiseGrowth{128,3}=GrowthRates.Protein{26,3};
PairwiseGrowth{128,4}=GrowthRates.Protein{34,4};
PairwiseGrowth{128,5}=GrowthRates.Protein{41,5};
PairwiseGrowth{128,6}=GrowthRates.Protein{47,6};
PairwiseGrowth{128,8}=GrowthRates.Protein{53,8};
PairwiseGrowth{128,9}=GrowthRates.Protein{54,9};
PairwiseGrowth{128,10}=GrowthRates.Protein{55,10};
PairwiseGrowth{128,11}=GrowthRates.Protein{56,11};
PairwiseGrowth{128,12}=GrowthRates.Protein{57,12};
PairwiseGrowth{129,2}=GrowthRates.Protein{18,2};
PairwiseGrowth{129,3}=GrowthRates.Protein{27,3};
PairwiseGrowth{129,4}=GrowthRates.Protein{35,4};
PairwiseGrowth{129,5}=GrowthRates.Protein{42,5};
PairwiseGrowth{129,6}=GrowthRates.Protein{48,6};
PairwiseGrowth{129,7}=GrowthRates.Protein{53,7};
PairwiseGrowth{129,9}=GrowthRates.Protein{58,9};
PairwiseGrowth{129,10}=GrowthRates.Protein{59,10};
PairwiseGrowth{129,11}=GrowthRates.Protein{60,11};
PairwiseGrowth{129,12}=GrowthRates.Protein{61,12};
PairwiseGrowth{130,2}=GrowthRates.Protein{19,2};
PairwiseGrowth{130,3}=GrowthRates.Protein{28,3};
PairwiseGrowth{130,4}=GrowthRates.Protein{36,4};
PairwiseGrowth{130,5}=GrowthRates.Protein{43,5};
PairwiseGrowth{130,6}=GrowthRates.Protein{49,6};
PairwiseGrowth{130,7}=GrowthRates.Protein{54,7};
PairwiseGrowth{130,8}=GrowthRates.Protein{58,8};
PairwiseGrowth{130,10}=GrowthRates.Protein{62,10};
PairwiseGrowth{130,11}=GrowthRates.Protein{63,11};
PairwiseGrowth{130,12}=GrowthRates.Protein{64,12};
PairwiseGrowth{131,2}=GrowthRates.Protein{20,2};
PairwiseGrowth{131,3}=GrowthRates.Protein{29,3};
PairwiseGrowth{131,4}=GrowthRates.Protein{37,4};
PairwiseGrowth{131,5}=GrowthRates.Protein{44,5};
PairwiseGrowth{131,6}=GrowthRates.Protein{50,6};
PairwiseGrowth{131,7}=GrowthRates.Protein{55,7};
PairwiseGrowth{131,8}=GrowthRates.Protein{59,8};
PairwiseGrowth{131,9}=GrowthRates.Protein{62,9};
PairwiseGrowth{131,11}=GrowthRates.Protein{65,11};
PairwiseGrowth{131,12}=GrowthRates.Protein{66,12};
PairwiseGrowth{132,2}=GrowthRates.Protein{21,2};
PairwiseGrowth{132,3}=GrowthRates.Protein{30,3};
PairwiseGrowth{132,4}=GrowthRates.Protein{38,4};
PairwiseGrowth{132,5}=GrowthRates.Protein{45,5};
PairwiseGrowth{132,6}=GrowthRates.Protein{51,6};
PairwiseGrowth{132,7}=GrowthRates.Protein{56,7};
PairwiseGrowth{132,8}=GrowthRates.Protein{60,8};
PairwiseGrowth{132,9}=GrowthRates.Protein{63,9};
PairwiseGrowth{132,10}=GrowthRates.Protein{65,10};
PairwiseGrowth{132,12}=GrowthRates.Protein{67,12};
PairwiseGrowth{133,2}=GrowthRates.Protein{22,2};
PairwiseGrowth{133,3}=GrowthRates.Protein{31,3};
PairwiseGrowth{133,4}=GrowthRates.Protein{39,4};
PairwiseGrowth{133,5}=GrowthRates.Protein{46,5};
PairwiseGrowth{133,6}=GrowthRates.Protein{52,6};
PairwiseGrowth{133,7}=GrowthRates.Protein{57,7};
PairwiseGrowth{133,8}=GrowthRates.Protein{61,8};
PairwiseGrowth{133,9}=GrowthRates.Protein{64,9};
PairwiseGrowth{133,10}=GrowthRates.Protein{66,10};
PairwiseGrowth{133,11}=GrowthRates.Protein{67,11};
PairwiseGrowth{134,3}=GrowthRates.Protein{79,3};
PairwiseGrowth{134,4}=GrowthRates.Protein{80,4};
PairwiseGrowth{134,5}=GrowthRates.Protein{81,5};
PairwiseGrowth{134,6}=GrowthRates.Protein{82,6};
PairwiseGrowth{134,7}=GrowthRates.Protein{83,7};
PairwiseGrowth{134,8}=GrowthRates.Protein{84,8};
PairwiseGrowth{134,9}=GrowthRates.Protein{85,9};
PairwiseGrowth{134,10}=GrowthRates.Protein{86,10};
PairwiseGrowth{134,11}=GrowthRates.Protein{87,11};
PairwiseGrowth{134,12}=GrowthRates.Protein{88,12};
PairwiseGrowth{135,2}=GrowthRates.Protein{79,2};
PairwiseGrowth{135,4}=GrowthRates.Protein{89,4};
PairwiseGrowth{135,5}=GrowthRates.Protein{90,5};
PairwiseGrowth{135,6}=GrowthRates.Protein{91,6};
PairwiseGrowth{135,7}=GrowthRates.Protein{92,7};
PairwiseGrowth{135,8}=GrowthRates.Protein{93,8};
PairwiseGrowth{135,9}=GrowthRates.Protein{94,9};
PairwiseGrowth{135,10}=GrowthRates.Protein{95,10};
PairwiseGrowth{135,11}=GrowthRates.Protein{96,11};
PairwiseGrowth{135,12}=GrowthRates.Protein{97,12};
PairwiseGrowth{136,2}=GrowthRates.Protein{80,2};
PairwiseGrowth{136,3}=GrowthRates.Protein{89,3};
PairwiseGrowth{136,5}=GrowthRates.Protein{98,5};
PairwiseGrowth{136,6}=GrowthRates.Protein{99,6};
PairwiseGrowth{136,7}=GrowthRates.Protein{100,7};
PairwiseGrowth{136,8}=GrowthRates.Protein{101,8};
PairwiseGrowth{136,9}=GrowthRates.Protein{102,9};
PairwiseGrowth{136,10}=GrowthRates.Protein{103,10};
PairwiseGrowth{136,11}=GrowthRates.Protein{104,11};
PairwiseGrowth{136,12}=GrowthRates.Protein{105,12};
PairwiseGrowth{137,2}=GrowthRates.Protein{81,2};
PairwiseGrowth{137,3}=GrowthRates.Protein{90,3};
PairwiseGrowth{137,4}=GrowthRates.Protein{98,4};
PairwiseGrowth{137,6}=GrowthRates.Protein{106,6};
PairwiseGrowth{137,7}=GrowthRates.Protein{107,7};
PairwiseGrowth{137,8}=GrowthRates.Protein{108,8};
PairwiseGrowth{137,9}=GrowthRates.Protein{109,9};
PairwiseGrowth{137,10}=GrowthRates.Protein{110,10};
PairwiseGrowth{137,11}=GrowthRates.Protein{111,11};
PairwiseGrowth{137,12}=GrowthRates.Protein{112,12};
PairwiseGrowth{138,2}=GrowthRates.Protein{82,2};
PairwiseGrowth{138,3}=GrowthRates.Protein{91,3};
PairwiseGrowth{138,4}=GrowthRates.Protein{99,4};
PairwiseGrowth{138,5}=GrowthRates.Protein{106,5};
PairwiseGrowth{138,7}=GrowthRates.Protein{113,7};
PairwiseGrowth{138,8}=GrowthRates.Protein{114,8};
PairwiseGrowth{138,9}=GrowthRates.Protein{115,9};
PairwiseGrowth{138,10}=GrowthRates.Protein{116,10};
PairwiseGrowth{138,11}=GrowthRates.Protein{117,11};
PairwiseGrowth{138,12}=GrowthRates.Protein{118,12};
PairwiseGrowth{139,2}=GrowthRates.Protein{83,2};
PairwiseGrowth{139,3}=GrowthRates.Protein{92,3};
PairwiseGrowth{139,4}=GrowthRates.Protein{100,4};
PairwiseGrowth{139,5}=GrowthRates.Protein{107,5};
PairwiseGrowth{139,6}=GrowthRates.Protein{113,6};
PairwiseGrowth{139,8}=GrowthRates.Protein{119,8};
PairwiseGrowth{139,9}=GrowthRates.Protein{120,9};
PairwiseGrowth{139,10}=GrowthRates.Protein{121,10};
PairwiseGrowth{139,11}=GrowthRates.Protein{122,11};
PairwiseGrowth{139,12}=GrowthRates.Protein{123,12};
PairwiseGrowth{140,2}=GrowthRates.Protein{84,2};
PairwiseGrowth{140,3}=GrowthRates.Protein{93,3};
PairwiseGrowth{140,4}=GrowthRates.Protein{101,4};
PairwiseGrowth{140,5}=GrowthRates.Protein{108,5};
PairwiseGrowth{140,6}=GrowthRates.Protein{114,6};
PairwiseGrowth{140,7}=GrowthRates.Protein{119,7};
PairwiseGrowth{140,9}=GrowthRates.Protein{124,9};
PairwiseGrowth{140,10}=GrowthRates.Protein{125,10};
PairwiseGrowth{140,11}=GrowthRates.Protein{126,11};
PairwiseGrowth{140,12}=GrowthRates.Protein{127,12};
PairwiseGrowth{141,2}=GrowthRates.Protein{85,2};
PairwiseGrowth{141,3}=GrowthRates.Protein{94,3};
PairwiseGrowth{141,4}=GrowthRates.Protein{102,4};
PairwiseGrowth{141,5}=GrowthRates.Protein{109,5};
PairwiseGrowth{141,6}=GrowthRates.Protein{115,6};
PairwiseGrowth{141,7}=GrowthRates.Protein{120,7};
PairwiseGrowth{141,8}=GrowthRates.Protein{124,8};
PairwiseGrowth{141,10}=GrowthRates.Protein{128,10};
PairwiseGrowth{141,11}=GrowthRates.Protein{129,11};
PairwiseGrowth{141,12}=GrowthRates.Protein{130,12};
PairwiseGrowth{142,2}=GrowthRates.Protein{86,2};
PairwiseGrowth{142,3}=GrowthRates.Protein{95,3};
PairwiseGrowth{142,4}=GrowthRates.Protein{103,4};
PairwiseGrowth{142,5}=GrowthRates.Protein{110,5};
PairwiseGrowth{142,6}=GrowthRates.Protein{116,6};
PairwiseGrowth{142,7}=GrowthRates.Protein{121,7};
PairwiseGrowth{142,8}=GrowthRates.Protein{125,8};
PairwiseGrowth{142,9}=GrowthRates.Protein{128,9};
PairwiseGrowth{142,11}=GrowthRates.Protein{131,11};
PairwiseGrowth{142,12}=GrowthRates.Protein{132,12};
PairwiseGrowth{143,2}=GrowthRates.Protein{87,2};
PairwiseGrowth{143,3}=GrowthRates.Protein{96,3};
PairwiseGrowth{143,4}=GrowthRates.Protein{104,4};
PairwiseGrowth{143,5}=GrowthRates.Protein{111,5};
PairwiseGrowth{143,6}=GrowthRates.Protein{117,6};
PairwiseGrowth{143,7}=GrowthRates.Protein{122,7};
PairwiseGrowth{143,8}=GrowthRates.Protein{126,8};
PairwiseGrowth{143,9}=GrowthRates.Protein{129,9};
PairwiseGrowth{143,10}=GrowthRates.Protein{131,10};
PairwiseGrowth{143,12}=GrowthRates.Protein{133,12};
PairwiseGrowth{144,2}=GrowthRates.Protein{88,2};
PairwiseGrowth{144,3}=GrowthRates.Protein{97,3};
PairwiseGrowth{144,4}=GrowthRates.Protein{105,4};
PairwiseGrowth{144,5}=GrowthRates.Protein{112,5};
PairwiseGrowth{144,6}=GrowthRates.Protein{118,6};
PairwiseGrowth{144,7}=GrowthRates.Protein{123,7};
PairwiseGrowth{144,8}=GrowthRates.Protein{127,8};
PairwiseGrowth{144,9}=GrowthRates.Protein{130,9};
PairwiseGrowth{144,10}=GrowthRates.Protein{132,10};
PairwiseGrowth{144,11}=GrowthRates.Protein{133,11};

save PairwiseGrowth PairwiseGrowth;

